# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class CoinsMarkets(object):

    """Implementation of the 'CoinsMarkets' model.

    Attributes:
        id (str): coin ID
        symbol (str): coin symbol
        name (str): coin name
        image (str): coin image url
        current_price (float): coin current price in currency
        market_cap (float): coin market cap in currency
        market_cap_rank (float): coin rank by market cap
        fully_diluted_valuation (float): coin fully diluted valuation (fdv) in
            currency
        total_volume (float): coin total trading volume in currency
        high_24_h (float): coin 24hr price high in currency
        low_24_h (float): coin 24hr price low in currency
        price_change_24_h (float): coin 24hr price change in currency
        price_change_percentage_24_h (float): coin 24hr price change in
            percentage
        market_cap_change_24_h (float): coin 24hr market cap change in currency
        market_cap_change_percentage_24_h (float): coin 24hr market cap change
            in percentage
        circulating_supply (float): coin circulating supply
        total_supply (float): coin total supply
        max_supply (float): coin max supply
        ath (float): coin all time high (ATH) in currency
        ath_change_percentage (float): coin all time high (ATH) change in
            percentage
        ath_date (datetime): coin all time high (ATH) date
        atl (float): coin all time low (atl) in currency
        atl_change_percentage (float): coin all time low (atl) change in
            percentage
        atl_date (datetime): coin all time low (atl) date
        roi (str): The model property of type str.
        last_updated (datetime): coin last updated timestamp

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "symbol": 'symbol',
        "name": 'name',
        "image": 'image',
        "current_price": 'current_price',
        "market_cap": 'market_cap',
        "market_cap_rank": 'market_cap_rank',
        "fully_diluted_valuation": 'fully_diluted_valuation',
        "total_volume": 'total_volume',
        "high_24_h": 'high_24h',
        "low_24_h": 'low_24h',
        "price_change_24_h": 'price_change_24h',
        "price_change_percentage_24_h": 'price_change_percentage_24h',
        "market_cap_change_24_h": 'market_cap_change_24h',
        "market_cap_change_percentage_24_h": 'market_cap_change_percentage_24h',
        "circulating_supply": 'circulating_supply',
        "total_supply": 'total_supply',
        "max_supply": 'max_supply',
        "ath": 'ath',
        "ath_change_percentage": 'ath_change_percentage',
        "ath_date": 'ath_date',
        "atl": 'atl',
        "atl_change_percentage": 'atl_change_percentage',
        "atl_date": 'atl_date',
        "roi": 'roi',
        "last_updated": 'last_updated'
    }

    _optionals = [
        'id',
        'symbol',
        'name',
        'image',
        'current_price',
        'market_cap',
        'market_cap_rank',
        'fully_diluted_valuation',
        'total_volume',
        'high_24_h',
        'low_24_h',
        'price_change_24_h',
        'price_change_percentage_24_h',
        'market_cap_change_24_h',
        'market_cap_change_percentage_24_h',
        'circulating_supply',
        'total_supply',
        'max_supply',
        'ath',
        'ath_change_percentage',
        'ath_date',
        'atl',
        'atl_change_percentage',
        'atl_date',
        'roi',
        'last_updated',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 symbol=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 image=APIHelper.SKIP,
                 current_price=APIHelper.SKIP,
                 market_cap=APIHelper.SKIP,
                 market_cap_rank=APIHelper.SKIP,
                 fully_diluted_valuation=APIHelper.SKIP,
                 total_volume=APIHelper.SKIP,
                 high_24_h=APIHelper.SKIP,
                 low_24_h=APIHelper.SKIP,
                 price_change_24_h=APIHelper.SKIP,
                 price_change_percentage_24_h=APIHelper.SKIP,
                 market_cap_change_24_h=APIHelper.SKIP,
                 market_cap_change_percentage_24_h=APIHelper.SKIP,
                 circulating_supply=APIHelper.SKIP,
                 total_supply=APIHelper.SKIP,
                 max_supply=APIHelper.SKIP,
                 ath=APIHelper.SKIP,
                 ath_change_percentage=APIHelper.SKIP,
                 ath_date=APIHelper.SKIP,
                 atl=APIHelper.SKIP,
                 atl_change_percentage=APIHelper.SKIP,
                 atl_date=APIHelper.SKIP,
                 roi=APIHelper.SKIP,
                 last_updated=APIHelper.SKIP):
        """Constructor for the CoinsMarkets class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if symbol is not APIHelper.SKIP:
            self.symbol = symbol 
        if name is not APIHelper.SKIP:
            self.name = name 
        if image is not APIHelper.SKIP:
            self.image = image 
        if current_price is not APIHelper.SKIP:
            self.current_price = current_price 
        if market_cap is not APIHelper.SKIP:
            self.market_cap = market_cap 
        if market_cap_rank is not APIHelper.SKIP:
            self.market_cap_rank = market_cap_rank 
        if fully_diluted_valuation is not APIHelper.SKIP:
            self.fully_diluted_valuation = fully_diluted_valuation 
        if total_volume is not APIHelper.SKIP:
            self.total_volume = total_volume 
        if high_24_h is not APIHelper.SKIP:
            self.high_24_h = high_24_h 
        if low_24_h is not APIHelper.SKIP:
            self.low_24_h = low_24_h 
        if price_change_24_h is not APIHelper.SKIP:
            self.price_change_24_h = price_change_24_h 
        if price_change_percentage_24_h is not APIHelper.SKIP:
            self.price_change_percentage_24_h = price_change_percentage_24_h 
        if market_cap_change_24_h is not APIHelper.SKIP:
            self.market_cap_change_24_h = market_cap_change_24_h 
        if market_cap_change_percentage_24_h is not APIHelper.SKIP:
            self.market_cap_change_percentage_24_h = market_cap_change_percentage_24_h 
        if circulating_supply is not APIHelper.SKIP:
            self.circulating_supply = circulating_supply 
        if total_supply is not APIHelper.SKIP:
            self.total_supply = total_supply 
        if max_supply is not APIHelper.SKIP:
            self.max_supply = max_supply 
        if ath is not APIHelper.SKIP:
            self.ath = ath 
        if ath_change_percentage is not APIHelper.SKIP:
            self.ath_change_percentage = ath_change_percentage 
        if ath_date is not APIHelper.SKIP:
            self.ath_date = APIHelper.apply_datetime_converter(ath_date, APIHelper.RFC3339DateTime) if ath_date else None 
        if atl is not APIHelper.SKIP:
            self.atl = atl 
        if atl_change_percentage is not APIHelper.SKIP:
            self.atl_change_percentage = atl_change_percentage 
        if atl_date is not APIHelper.SKIP:
            self.atl_date = APIHelper.apply_datetime_converter(atl_date, APIHelper.RFC3339DateTime) if atl_date else None 
        if roi is not APIHelper.SKIP:
            self.roi = roi 
        if last_updated is not APIHelper.SKIP:
            self.last_updated = APIHelper.apply_datetime_converter(last_updated, APIHelper.RFC3339DateTime) if last_updated else None 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        symbol = dictionary.get("symbol") if dictionary.get("symbol") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        image = dictionary.get("image") if dictionary.get("image") else APIHelper.SKIP
        current_price = dictionary.get("current_price") if dictionary.get("current_price") else APIHelper.SKIP
        market_cap = dictionary.get("market_cap") if dictionary.get("market_cap") else APIHelper.SKIP
        market_cap_rank = dictionary.get("market_cap_rank") if dictionary.get("market_cap_rank") else APIHelper.SKIP
        fully_diluted_valuation = dictionary.get("fully_diluted_valuation") if dictionary.get("fully_diluted_valuation") else APIHelper.SKIP
        total_volume = dictionary.get("total_volume") if dictionary.get("total_volume") else APIHelper.SKIP
        high_24_h = dictionary.get("high_24h") if dictionary.get("high_24h") else APIHelper.SKIP
        low_24_h = dictionary.get("low_24h") if dictionary.get("low_24h") else APIHelper.SKIP
        price_change_24_h = dictionary.get("price_change_24h") if dictionary.get("price_change_24h") else APIHelper.SKIP
        price_change_percentage_24_h = dictionary.get("price_change_percentage_24h") if dictionary.get("price_change_percentage_24h") else APIHelper.SKIP
        market_cap_change_24_h = dictionary.get("market_cap_change_24h") if dictionary.get("market_cap_change_24h") else APIHelper.SKIP
        market_cap_change_percentage_24_h = dictionary.get("market_cap_change_percentage_24h") if dictionary.get("market_cap_change_percentage_24h") else APIHelper.SKIP
        circulating_supply = dictionary.get("circulating_supply") if dictionary.get("circulating_supply") else APIHelper.SKIP
        total_supply = dictionary.get("total_supply") if dictionary.get("total_supply") else APIHelper.SKIP
        max_supply = dictionary.get("max_supply") if dictionary.get("max_supply") else APIHelper.SKIP
        ath = dictionary.get("ath") if dictionary.get("ath") else APIHelper.SKIP
        ath_change_percentage = dictionary.get("ath_change_percentage") if dictionary.get("ath_change_percentage") else APIHelper.SKIP
        ath_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("ath_date")).datetime if dictionary.get("ath_date") else APIHelper.SKIP
        atl = dictionary.get("atl") if dictionary.get("atl") else APIHelper.SKIP
        atl_change_percentage = dictionary.get("atl_change_percentage") if dictionary.get("atl_change_percentage") else APIHelper.SKIP
        atl_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("atl_date")).datetime if dictionary.get("atl_date") else APIHelper.SKIP
        roi = dictionary.get("roi") if dictionary.get("roi") else APIHelper.SKIP
        last_updated = APIHelper.RFC3339DateTime.from_value(dictionary.get("last_updated")).datetime if dictionary.get("last_updated") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   symbol,
                   name,
                   image,
                   current_price,
                   market_cap,
                   market_cap_rank,
                   fully_diluted_valuation,
                   total_volume,
                   high_24_h,
                   low_24_h,
                   price_change_24_h,
                   price_change_percentage_24_h,
                   market_cap_change_24_h,
                   market_cap_change_percentage_24_h,
                   circulating_supply,
                   total_supply,
                   max_supply,
                   ath,
                   ath_change_percentage,
                   ath_date,
                   atl,
                   atl_change_percentage,
                   atl_date,
                   roi,
                   last_updated)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'image={(self.image if hasattr(self, "image") else None)!r}, '
                f'current_price={(self.current_price if hasattr(self, "current_price") else None)!r}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!r}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!r}, '
                f'fully_diluted_valuation={(self.fully_diluted_valuation if hasattr(self, "fully_diluted_valuation") else None)!r}, '
                f'total_volume={(self.total_volume if hasattr(self, "total_volume") else None)!r}, '
                f'high_24_h={(self.high_24_h if hasattr(self, "high_24_h") else None)!r}, '
                f'low_24_h={(self.low_24_h if hasattr(self, "low_24_h") else None)!r}, '
                f'price_change_24_h={(self.price_change_24_h if hasattr(self, "price_change_24_h") else None)!r}, '
                f'price_change_percentage_24_h={(self.price_change_percentage_24_h if hasattr(self, "price_change_percentage_24_h") else None)!r}, '
                f'market_cap_change_24_h={(self.market_cap_change_24_h if hasattr(self, "market_cap_change_24_h") else None)!r}, '
                f'market_cap_change_percentage_24_h={(self.market_cap_change_percentage_24_h if hasattr(self, "market_cap_change_percentage_24_h") else None)!r}, '
                f'circulating_supply={(self.circulating_supply if hasattr(self, "circulating_supply") else None)!r}, '
                f'total_supply={(self.total_supply if hasattr(self, "total_supply") else None)!r}, '
                f'max_supply={(self.max_supply if hasattr(self, "max_supply") else None)!r}, '
                f'ath={(self.ath if hasattr(self, "ath") else None)!r}, '
                f'ath_change_percentage={(self.ath_change_percentage if hasattr(self, "ath_change_percentage") else None)!r}, '
                f'ath_date={(self.ath_date if hasattr(self, "ath_date") else None)!r}, '
                f'atl={(self.atl if hasattr(self, "atl") else None)!r}, '
                f'atl_change_percentage={(self.atl_change_percentage if hasattr(self, "atl_change_percentage") else None)!r}, '
                f'atl_date={(self.atl_date if hasattr(self, "atl_date") else None)!r}, '
                f'roi={(self.roi if hasattr(self, "roi") else None)!r}, '
                f'last_updated={(self.last_updated if hasattr(self, "last_updated") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'image={(self.image if hasattr(self, "image") else None)!s}, '
                f'current_price={(self.current_price if hasattr(self, "current_price") else None)!s}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!s}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!s}, '
                f'fully_diluted_valuation={(self.fully_diluted_valuation if hasattr(self, "fully_diluted_valuation") else None)!s}, '
                f'total_volume={(self.total_volume if hasattr(self, "total_volume") else None)!s}, '
                f'high_24_h={(self.high_24_h if hasattr(self, "high_24_h") else None)!s}, '
                f'low_24_h={(self.low_24_h if hasattr(self, "low_24_h") else None)!s}, '
                f'price_change_24_h={(self.price_change_24_h if hasattr(self, "price_change_24_h") else None)!s}, '
                f'price_change_percentage_24_h={(self.price_change_percentage_24_h if hasattr(self, "price_change_percentage_24_h") else None)!s}, '
                f'market_cap_change_24_h={(self.market_cap_change_24_h if hasattr(self, "market_cap_change_24_h") else None)!s}, '
                f'market_cap_change_percentage_24_h={(self.market_cap_change_percentage_24_h if hasattr(self, "market_cap_change_percentage_24_h") else None)!s}, '
                f'circulating_supply={(self.circulating_supply if hasattr(self, "circulating_supply") else None)!s}, '
                f'total_supply={(self.total_supply if hasattr(self, "total_supply") else None)!s}, '
                f'max_supply={(self.max_supply if hasattr(self, "max_supply") else None)!s}, '
                f'ath={(self.ath if hasattr(self, "ath") else None)!s}, '
                f'ath_change_percentage={(self.ath_change_percentage if hasattr(self, "ath_change_percentage") else None)!s}, '
                f'ath_date={(self.ath_date if hasattr(self, "ath_date") else None)!s}, '
                f'atl={(self.atl if hasattr(self, "atl") else None)!s}, '
                f'atl_change_percentage={(self.atl_change_percentage if hasattr(self, "atl_change_percentage") else None)!s}, '
                f'atl_date={(self.atl_date if hasattr(self, "atl_date") else None)!s}, '
                f'roi={(self.roi if hasattr(self, "roi") else None)!s}, '
                f'last_updated={(self.last_updated if hasattr(self, "last_updated") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.ath_1 import Ath1
from coingeckopublicapiv3.models.ath_change_percentage_1 import AthChangePercentage1
from coingeckopublicapiv3.models.ath_date_1 import AthDate1
from coingeckopublicapiv3.models.banner_image import BannerImage
from coingeckopublicapiv3.models.explorer import Explorer
from coingeckopublicapiv3.models.floor_price import FloorPrice
from coingeckopublicapiv3.models.floor_price_1_y_percentage_change import FloorPrice1yPercentageChange
from coingeckopublicapiv3.models.floor_price_14_d_percentage_change import FloorPrice14dPercentageChange
from coingeckopublicapiv3.models.floor_price_24_h_percentage_change import FloorPrice24hPercentageChange
from coingeckopublicapiv3.models.floor_price_30_d_percentage_change import FloorPrice30dPercentageChange
from coingeckopublicapiv3.models.floor_price_60_d_percentage_change import FloorPrice60dPercentageChange
from coingeckopublicapiv3.models.floor_price_7_d_percentage_change import FloorPrice7dPercentageChange
from coingeckopublicapiv3.models.image_3 import Image3
from coingeckopublicapiv3.models.links_1 import Links1
from coingeckopublicapiv3.models.market_cap_2 import MarketCap2
from coingeckopublicapiv3.models.market_cap_24_h_percentage_change import MarketCap24hPercentageChange
from coingeckopublicapiv3.models.volume_24_h import Volume24h
from coingeckopublicapiv3.models.volume_24_h_percentage_change import Volume24hPercentageChange


class NFTData(object):

    """Implementation of the 'NFTData' model.

    Attributes:
        id (str): NFT collection ID
        contract_address (str): NFT collection contract address
        asset_platform_id (str): NFT collection asset platform ID
        name (str): NFT collection name
        symbol (str): NFT collection symbol
        image (Image3): NFT collection image url
        banner_image (BannerImage): NFT collection banner image url
        description (str): NFT collection description
        native_currency (str): NFT collection native currency
        native_currency_symbol (str): NFT collection native currency symbol
        market_cap_rank (float): coin market cap rank
        floor_price (FloorPrice): NFT collection floor price
        market_cap (MarketCap2): NFT collection market cap
        volume_24_h (Volume24h): NFT collection volume in 24 hours
        floor_price_in_usd_24_h_percentage_change (float): NFT collection
            floor price in usd 24 hours percentage change
        floor_price_24_h_percentage_change (FloorPrice24hPercentageChange):
            The model property of type FloorPrice24hPercentageChange.
        market_cap_24_h_percentage_change (MarketCap24hPercentageChange): NFT
            collection market cap 24 hours percentage change
        volume_24_h_percentage_change (Volume24hPercentageChange): NFT
            collection volume in 24 hours percentage change
        number_of_unique_addresses (float): number of unique address owning
            the NFTs
        number_of_unique_addresses_24_h_percentage_change (float): number of
            unique address owning the NFTs 24 hours percentage change
        volume_in_usd_24_h_percentage_change (float): NFT collection volume in
            usd 24 hours percentage change
        total_supply (float): NFT collection total supply
        one_day_sales (float): NFT collection one day sales
        one_day_sales_24_h_percentage_change (float): NFT collection one day
            sales 24 hours percentage change
        one_day_average_sale_price (float): NFT collection one day average
            sale price
        one_day_average_sale_price_24_h_percentage_change (float): NFT
            collection one day average sale price 24 hours percentage change
        links (Links1): NFT collection links
        floor_price_7_d_percentage_change (FloorPrice7dPercentageChange): NFT
            collection floor price 7 days percentage change
        floor_price_14_d_percentage_change (FloorPrice14dPercentageChange):
            NFT collection floor price 14 days percentage change
        floor_price_30_d_percentage_change (FloorPrice30dPercentageChange):
            NFT collection floor price 30 days percentage change
        floor_price_60_d_percentage_change (FloorPrice60dPercentageChange):
            NFT collection floor price 60 days percentage change
        floor_price_1_y_percentage_change (FloorPrice1yPercentageChange): NFT
            collection floor price 1 year percentage change
        explorers (List[Explorer]): NFT collection block explorers links
        user_favorites_count (float): NFT collection user favorites count
        ath (Ath1): NFT collection all time highs
        ath_change_percentage (AthChangePercentage1): NFT collection all time
            highs change percentage
        ath_date (AthDate1): NFT collection all time highs date

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "contract_address": 'contract_address',
        "asset_platform_id": 'asset_platform_id',
        "name": 'name',
        "symbol": 'symbol',
        "image": 'image',
        "banner_image": 'banner_image',
        "description": 'description',
        "native_currency": 'native_currency',
        "native_currency_symbol": 'native_currency_symbol',
        "market_cap_rank": 'market_cap_rank',
        "floor_price": 'floor_price',
        "market_cap": 'market_cap',
        "volume_24_h": 'volume_24h',
        "floor_price_in_usd_24_h_percentage_change": 'floor_price_in_usd_24h_percentage_change',
        "floor_price_24_h_percentage_change": 'floor_price_24h_percentage_change',
        "market_cap_24_h_percentage_change": 'market_cap_24h_percentage_change',
        "volume_24_h_percentage_change": 'volume_24h_percentage_change',
        "number_of_unique_addresses": 'number_of_unique_addresses',
        "number_of_unique_addresses_24_h_percentage_change": 'number_of_unique_addresses_24h_percentage_change',
        "volume_in_usd_24_h_percentage_change": 'volume_in_usd_24h_percentage_change',
        "total_supply": 'total_supply',
        "one_day_sales": 'one_day_sales',
        "one_day_sales_24_h_percentage_change": 'one_day_sales_24h_percentage_change',
        "one_day_average_sale_price": 'one_day_average_sale_price',
        "one_day_average_sale_price_24_h_percentage_change": 'one_day_average_sale_price_24h_percentage_change',
        "links": 'links',
        "floor_price_7_d_percentage_change": 'floor_price_7d_percentage_change',
        "floor_price_14_d_percentage_change": 'floor_price_14d_percentage_change',
        "floor_price_30_d_percentage_change": 'floor_price_30d_percentage_change',
        "floor_price_60_d_percentage_change": 'floor_price_60d_percentage_change',
        "floor_price_1_y_percentage_change": 'floor_price_1y_percentage_change',
        "explorers": 'explorers',
        "user_favorites_count": 'user_favorites_count',
        "ath": 'ath',
        "ath_change_percentage": 'ath_change_percentage',
        "ath_date": 'ath_date'
    }

    _optionals = [
        'id',
        'contract_address',
        'asset_platform_id',
        'name',
        'symbol',
        'image',
        'banner_image',
        'description',
        'native_currency',
        'native_currency_symbol',
        'market_cap_rank',
        'floor_price',
        'market_cap',
        'volume_24_h',
        'floor_price_in_usd_24_h_percentage_change',
        'floor_price_24_h_percentage_change',
        'market_cap_24_h_percentage_change',
        'volume_24_h_percentage_change',
        'number_of_unique_addresses',
        'number_of_unique_addresses_24_h_percentage_change',
        'volume_in_usd_24_h_percentage_change',
        'total_supply',
        'one_day_sales',
        'one_day_sales_24_h_percentage_change',
        'one_day_average_sale_price',
        'one_day_average_sale_price_24_h_percentage_change',
        'links',
        'floor_price_7_d_percentage_change',
        'floor_price_14_d_percentage_change',
        'floor_price_30_d_percentage_change',
        'floor_price_60_d_percentage_change',
        'floor_price_1_y_percentage_change',
        'explorers',
        'user_favorites_count',
        'ath',
        'ath_change_percentage',
        'ath_date',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 contract_address=APIHelper.SKIP,
                 asset_platform_id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 symbol=APIHelper.SKIP,
                 image=APIHelper.SKIP,
                 banner_image=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 native_currency=APIHelper.SKIP,
                 native_currency_symbol=APIHelper.SKIP,
                 market_cap_rank=APIHelper.SKIP,
                 floor_price=APIHelper.SKIP,
                 market_cap=APIHelper.SKIP,
                 volume_24_h=APIHelper.SKIP,
                 floor_price_in_usd_24_h_percentage_change=APIHelper.SKIP,
                 floor_price_24_h_percentage_change=APIHelper.SKIP,
                 market_cap_24_h_percentage_change=APIHelper.SKIP,
                 volume_24_h_percentage_change=APIHelper.SKIP,
                 number_of_unique_addresses=APIHelper.SKIP,
                 number_of_unique_addresses_24_h_percentage_change=APIHelper.SKIP,
                 volume_in_usd_24_h_percentage_change=APIHelper.SKIP,
                 total_supply=APIHelper.SKIP,
                 one_day_sales=APIHelper.SKIP,
                 one_day_sales_24_h_percentage_change=APIHelper.SKIP,
                 one_day_average_sale_price=APIHelper.SKIP,
                 one_day_average_sale_price_24_h_percentage_change=APIHelper.SKIP,
                 links=APIHelper.SKIP,
                 floor_price_7_d_percentage_change=APIHelper.SKIP,
                 floor_price_14_d_percentage_change=APIHelper.SKIP,
                 floor_price_30_d_percentage_change=APIHelper.SKIP,
                 floor_price_60_d_percentage_change=APIHelper.SKIP,
                 floor_price_1_y_percentage_change=APIHelper.SKIP,
                 explorers=APIHelper.SKIP,
                 user_favorites_count=APIHelper.SKIP,
                 ath=APIHelper.SKIP,
                 ath_change_percentage=APIHelper.SKIP,
                 ath_date=APIHelper.SKIP):
        """Constructor for the NFTData class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if contract_address is not APIHelper.SKIP:
            self.contract_address = contract_address 
        if asset_platform_id is not APIHelper.SKIP:
            self.asset_platform_id = asset_platform_id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if symbol is not APIHelper.SKIP:
            self.symbol = symbol 
        if image is not APIHelper.SKIP:
            self.image = image 
        if banner_image is not APIHelper.SKIP:
            self.banner_image = banner_image 
        if description is not APIHelper.SKIP:
            self.description = description 
        if native_currency is not APIHelper.SKIP:
            self.native_currency = native_currency 
        if native_currency_symbol is not APIHelper.SKIP:
            self.native_currency_symbol = native_currency_symbol 
        if market_cap_rank is not APIHelper.SKIP:
            self.market_cap_rank = market_cap_rank 
        if floor_price is not APIHelper.SKIP:
            self.floor_price = floor_price 
        if market_cap is not APIHelper.SKIP:
            self.market_cap = market_cap 
        if volume_24_h is not APIHelper.SKIP:
            self.volume_24_h = volume_24_h 
        if floor_price_in_usd_24_h_percentage_change is not APIHelper.SKIP:
            self.floor_price_in_usd_24_h_percentage_change = floor_price_in_usd_24_h_percentage_change 
        if floor_price_24_h_percentage_change is not APIHelper.SKIP:
            self.floor_price_24_h_percentage_change = floor_price_24_h_percentage_change 
        if market_cap_24_h_percentage_change is not APIHelper.SKIP:
            self.market_cap_24_h_percentage_change = market_cap_24_h_percentage_change 
        if volume_24_h_percentage_change is not APIHelper.SKIP:
            self.volume_24_h_percentage_change = volume_24_h_percentage_change 
        if number_of_unique_addresses is not APIHelper.SKIP:
            self.number_of_unique_addresses = number_of_unique_addresses 
        if number_of_unique_addresses_24_h_percentage_change is not APIHelper.SKIP:
            self.number_of_unique_addresses_24_h_percentage_change = number_of_unique_addresses_24_h_percentage_change 
        if volume_in_usd_24_h_percentage_change is not APIHelper.SKIP:
            self.volume_in_usd_24_h_percentage_change = volume_in_usd_24_h_percentage_change 
        if total_supply is not APIHelper.SKIP:
            self.total_supply = total_supply 
        if one_day_sales is not APIHelper.SKIP:
            self.one_day_sales = one_day_sales 
        if one_day_sales_24_h_percentage_change is not APIHelper.SKIP:
            self.one_day_sales_24_h_percentage_change = one_day_sales_24_h_percentage_change 
        if one_day_average_sale_price is not APIHelper.SKIP:
            self.one_day_average_sale_price = one_day_average_sale_price 
        if one_day_average_sale_price_24_h_percentage_change is not APIHelper.SKIP:
            self.one_day_average_sale_price_24_h_percentage_change = one_day_average_sale_price_24_h_percentage_change 
        if links is not APIHelper.SKIP:
            self.links = links 
        if floor_price_7_d_percentage_change is not APIHelper.SKIP:
            self.floor_price_7_d_percentage_change = floor_price_7_d_percentage_change 
        if floor_price_14_d_percentage_change is not APIHelper.SKIP:
            self.floor_price_14_d_percentage_change = floor_price_14_d_percentage_change 
        if floor_price_30_d_percentage_change is not APIHelper.SKIP:
            self.floor_price_30_d_percentage_change = floor_price_30_d_percentage_change 
        if floor_price_60_d_percentage_change is not APIHelper.SKIP:
            self.floor_price_60_d_percentage_change = floor_price_60_d_percentage_change 
        if floor_price_1_y_percentage_change is not APIHelper.SKIP:
            self.floor_price_1_y_percentage_change = floor_price_1_y_percentage_change 
        if explorers is not APIHelper.SKIP:
            self.explorers = explorers 
        if user_favorites_count is not APIHelper.SKIP:
            self.user_favorites_count = user_favorites_count 
        if ath is not APIHelper.SKIP:
            self.ath = ath 
        if ath_change_percentage is not APIHelper.SKIP:
            self.ath_change_percentage = ath_change_percentage 
        if ath_date is not APIHelper.SKIP:
            self.ath_date = ath_date 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        contract_address = dictionary.get("contract_address") if dictionary.get("contract_address") else APIHelper.SKIP
        asset_platform_id = dictionary.get("asset_platform_id") if dictionary.get("asset_platform_id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        symbol = dictionary.get("symbol") if dictionary.get("symbol") else APIHelper.SKIP
        image = Image3.from_dictionary(dictionary.get('image')) if 'image' in dictionary.keys() else APIHelper.SKIP
        banner_image = BannerImage.from_dictionary(dictionary.get('banner_image')) if 'banner_image' in dictionary.keys() else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        native_currency = dictionary.get("native_currency") if dictionary.get("native_currency") else APIHelper.SKIP
        native_currency_symbol = dictionary.get("native_currency_symbol") if dictionary.get("native_currency_symbol") else APIHelper.SKIP
        market_cap_rank = dictionary.get("market_cap_rank") if dictionary.get("market_cap_rank") else APIHelper.SKIP
        floor_price = FloorPrice.from_dictionary(dictionary.get('floor_price')) if 'floor_price' in dictionary.keys() else APIHelper.SKIP
        market_cap = MarketCap2.from_dictionary(dictionary.get('market_cap')) if 'market_cap' in dictionary.keys() else APIHelper.SKIP
        volume_24_h = Volume24h.from_dictionary(dictionary.get('volume_24h')) if 'volume_24h' in dictionary.keys() else APIHelper.SKIP
        floor_price_in_usd_24_h_percentage_change = dictionary.get("floor_price_in_usd_24h_percentage_change") if dictionary.get("floor_price_in_usd_24h_percentage_change") else APIHelper.SKIP
        floor_price_24_h_percentage_change = FloorPrice24hPercentageChange.from_dictionary(dictionary.get('floor_price_24h_percentage_change')) if 'floor_price_24h_percentage_change' in dictionary.keys() else APIHelper.SKIP
        market_cap_24_h_percentage_change = MarketCap24hPercentageChange.from_dictionary(dictionary.get('market_cap_24h_percentage_change')) if 'market_cap_24h_percentage_change' in dictionary.keys() else APIHelper.SKIP
        volume_24_h_percentage_change = Volume24hPercentageChange.from_dictionary(dictionary.get('volume_24h_percentage_change')) if 'volume_24h_percentage_change' in dictionary.keys() else APIHelper.SKIP
        number_of_unique_addresses = dictionary.get("number_of_unique_addresses") if dictionary.get("number_of_unique_addresses") else APIHelper.SKIP
        number_of_unique_addresses_24_h_percentage_change = dictionary.get("number_of_unique_addresses_24h_percentage_change") if dictionary.get("number_of_unique_addresses_24h_percentage_change") else APIHelper.SKIP
        volume_in_usd_24_h_percentage_change = dictionary.get("volume_in_usd_24h_percentage_change") if dictionary.get("volume_in_usd_24h_percentage_change") else APIHelper.SKIP
        total_supply = dictionary.get("total_supply") if dictionary.get("total_supply") else APIHelper.SKIP
        one_day_sales = dictionary.get("one_day_sales") if dictionary.get("one_day_sales") else APIHelper.SKIP
        one_day_sales_24_h_percentage_change = dictionary.get("one_day_sales_24h_percentage_change") if dictionary.get("one_day_sales_24h_percentage_change") else APIHelper.SKIP
        one_day_average_sale_price = dictionary.get("one_day_average_sale_price") if dictionary.get("one_day_average_sale_price") else APIHelper.SKIP
        one_day_average_sale_price_24_h_percentage_change = dictionary.get("one_day_average_sale_price_24h_percentage_change") if dictionary.get("one_day_average_sale_price_24h_percentage_change") else APIHelper.SKIP
        links = Links1.from_dictionary(dictionary.get('links')) if 'links' in dictionary.keys() else APIHelper.SKIP
        floor_price_7_d_percentage_change = FloorPrice7dPercentageChange.from_dictionary(dictionary.get('floor_price_7d_percentage_change')) if 'floor_price_7d_percentage_change' in dictionary.keys() else APIHelper.SKIP
        floor_price_14_d_percentage_change = FloorPrice14dPercentageChange.from_dictionary(dictionary.get('floor_price_14d_percentage_change')) if 'floor_price_14d_percentage_change' in dictionary.keys() else APIHelper.SKIP
        floor_price_30_d_percentage_change = FloorPrice30dPercentageChange.from_dictionary(dictionary.get('floor_price_30d_percentage_change')) if 'floor_price_30d_percentage_change' in dictionary.keys() else APIHelper.SKIP
        floor_price_60_d_percentage_change = FloorPrice60dPercentageChange.from_dictionary(dictionary.get('floor_price_60d_percentage_change')) if 'floor_price_60d_percentage_change' in dictionary.keys() else APIHelper.SKIP
        floor_price_1_y_percentage_change = FloorPrice1yPercentageChange.from_dictionary(dictionary.get('floor_price_1y_percentage_change')) if 'floor_price_1y_percentage_change' in dictionary.keys() else APIHelper.SKIP
        explorers = None
        if dictionary.get('explorers') is not None:
            explorers = [Explorer.from_dictionary(x) for x in dictionary.get('explorers')]
        else:
            explorers = APIHelper.SKIP
        user_favorites_count = dictionary.get("user_favorites_count") if dictionary.get("user_favorites_count") else APIHelper.SKIP
        ath = Ath1.from_dictionary(dictionary.get('ath')) if 'ath' in dictionary.keys() else APIHelper.SKIP
        ath_change_percentage = AthChangePercentage1.from_dictionary(dictionary.get('ath_change_percentage')) if 'ath_change_percentage' in dictionary.keys() else APIHelper.SKIP
        ath_date = AthDate1.from_dictionary(dictionary.get('ath_date')) if 'ath_date' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   contract_address,
                   asset_platform_id,
                   name,
                   symbol,
                   image,
                   banner_image,
                   description,
                   native_currency,
                   native_currency_symbol,
                   market_cap_rank,
                   floor_price,
                   market_cap,
                   volume_24_h,
                   floor_price_in_usd_24_h_percentage_change,
                   floor_price_24_h_percentage_change,
                   market_cap_24_h_percentage_change,
                   volume_24_h_percentage_change,
                   number_of_unique_addresses,
                   number_of_unique_addresses_24_h_percentage_change,
                   volume_in_usd_24_h_percentage_change,
                   total_supply,
                   one_day_sales,
                   one_day_sales_24_h_percentage_change,
                   one_day_average_sale_price,
                   one_day_average_sale_price_24_h_percentage_change,
                   links,
                   floor_price_7_d_percentage_change,
                   floor_price_14_d_percentage_change,
                   floor_price_30_d_percentage_change,
                   floor_price_60_d_percentage_change,
                   floor_price_1_y_percentage_change,
                   explorers,
                   user_favorites_count,
                   ath,
                   ath_change_percentage,
                   ath_date)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'contract_address={(self.contract_address if hasattr(self, "contract_address") else None)!r}, '
                f'asset_platform_id={(self.asset_platform_id if hasattr(self, "asset_platform_id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!r}, '
                f'image={(self.image if hasattr(self, "image") else None)!r}, '
                f'banner_image={(self.banner_image if hasattr(self, "banner_image") else None)!r}, '
                f'description={(self.description if hasattr(self, "description") else None)!r}, '
                f'native_currency={(self.native_currency if hasattr(self, "native_currency") else None)!r}, '
                f'native_currency_symbol={(self.native_currency_symbol if hasattr(self, "native_currency_symbol") else None)!r}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!r}, '
                f'floor_price={(self.floor_price if hasattr(self, "floor_price") else None)!r}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!r}, '
                f'volume_24_h={(self.volume_24_h if hasattr(self, "volume_24_h") else None)!r}, '
                f'floor_price_in_usd_24_h_percentage_change={(self.floor_price_in_usd_24_h_percentage_change if hasattr(self, "floor_price_in_usd_24_h_percentage_change") else None)!r}, '
                f'floor_price_24_h_percentage_change={(self.floor_price_24_h_percentage_change if hasattr(self, "floor_price_24_h_percentage_change") else None)!r}, '
                f'market_cap_24_h_percentage_change={(self.market_cap_24_h_percentage_change if hasattr(self, "market_cap_24_h_percentage_change") else None)!r}, '
                f'volume_24_h_percentage_change={(self.volume_24_h_percentage_change if hasattr(self, "volume_24_h_percentage_change") else None)!r}, '
                f'number_of_unique_addresses={(self.number_of_unique_addresses if hasattr(self, "number_of_unique_addresses") else None)!r}, '
                f'number_of_unique_addresses_24_h_percentage_change={(self.number_of_unique_addresses_24_h_percentage_change if hasattr(self, "number_of_unique_addresses_24_h_percentage_change") else None)!r}, '
                f'volume_in_usd_24_h_percentage_change={(self.volume_in_usd_24_h_percentage_change if hasattr(self, "volume_in_usd_24_h_percentage_change") else None)!r}, '
                f'total_supply={(self.total_supply if hasattr(self, "total_supply") else None)!r}, '
                f'one_day_sales={(self.one_day_sales if hasattr(self, "one_day_sales") else None)!r}, '
                f'one_day_sales_24_h_percentage_change={(self.one_day_sales_24_h_percentage_change if hasattr(self, "one_day_sales_24_h_percentage_change") else None)!r}, '
                f'one_day_average_sale_price={(self.one_day_average_sale_price if hasattr(self, "one_day_average_sale_price") else None)!r}, '
                f'one_day_average_sale_price_24_h_percentage_change={(self.one_day_average_sale_price_24_h_percentage_change if hasattr(self, "one_day_average_sale_price_24_h_percentage_change") else None)!r}, '
                f'links={(self.links if hasattr(self, "links") else None)!r}, '
                f'floor_price_7_d_percentage_change={(self.floor_price_7_d_percentage_change if hasattr(self, "floor_price_7_d_percentage_change") else None)!r}, '
                f'floor_price_14_d_percentage_change={(self.floor_price_14_d_percentage_change if hasattr(self, "floor_price_14_d_percentage_change") else None)!r}, '
                f'floor_price_30_d_percentage_change={(self.floor_price_30_d_percentage_change if hasattr(self, "floor_price_30_d_percentage_change") else None)!r}, '
                f'floor_price_60_d_percentage_change={(self.floor_price_60_d_percentage_change if hasattr(self, "floor_price_60_d_percentage_change") else None)!r}, '
                f'floor_price_1_y_percentage_change={(self.floor_price_1_y_percentage_change if hasattr(self, "floor_price_1_y_percentage_change") else None)!r}, '
                f'explorers={(self.explorers if hasattr(self, "explorers") else None)!r}, '
                f'user_favorites_count={(self.user_favorites_count if hasattr(self, "user_favorites_count") else None)!r}, '
                f'ath={(self.ath if hasattr(self, "ath") else None)!r}, '
                f'ath_change_percentage={(self.ath_change_percentage if hasattr(self, "ath_change_percentage") else None)!r}, '
                f'ath_date={(self.ath_date if hasattr(self, "ath_date") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'contract_address={(self.contract_address if hasattr(self, "contract_address") else None)!s}, '
                f'asset_platform_id={(self.asset_platform_id if hasattr(self, "asset_platform_id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!s}, '
                f'image={(self.image if hasattr(self, "image") else None)!s}, '
                f'banner_image={(self.banner_image if hasattr(self, "banner_image") else None)!s}, '
                f'description={(self.description if hasattr(self, "description") else None)!s}, '
                f'native_currency={(self.native_currency if hasattr(self, "native_currency") else None)!s}, '
                f'native_currency_symbol={(self.native_currency_symbol if hasattr(self, "native_currency_symbol") else None)!s}, '
                f'market_cap_rank={(self.market_cap_rank if hasattr(self, "market_cap_rank") else None)!s}, '
                f'floor_price={(self.floor_price if hasattr(self, "floor_price") else None)!s}, '
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!s}, '
                f'volume_24_h={(self.volume_24_h if hasattr(self, "volume_24_h") else None)!s}, '
                f'floor_price_in_usd_24_h_percentage_change={(self.floor_price_in_usd_24_h_percentage_change if hasattr(self, "floor_price_in_usd_24_h_percentage_change") else None)!s}, '
                f'floor_price_24_h_percentage_change={(self.floor_price_24_h_percentage_change if hasattr(self, "floor_price_24_h_percentage_change") else None)!s}, '
                f'market_cap_24_h_percentage_change={(self.market_cap_24_h_percentage_change if hasattr(self, "market_cap_24_h_percentage_change") else None)!s}, '
                f'volume_24_h_percentage_change={(self.volume_24_h_percentage_change if hasattr(self, "volume_24_h_percentage_change") else None)!s}, '
                f'number_of_unique_addresses={(self.number_of_unique_addresses if hasattr(self, "number_of_unique_addresses") else None)!s}, '
                f'number_of_unique_addresses_24_h_percentage_change={(self.number_of_unique_addresses_24_h_percentage_change if hasattr(self, "number_of_unique_addresses_24_h_percentage_change") else None)!s}, '
                f'volume_in_usd_24_h_percentage_change={(self.volume_in_usd_24_h_percentage_change if hasattr(self, "volume_in_usd_24_h_percentage_change") else None)!s}, '
                f'total_supply={(self.total_supply if hasattr(self, "total_supply") else None)!s}, '
                f'one_day_sales={(self.one_day_sales if hasattr(self, "one_day_sales") else None)!s}, '
                f'one_day_sales_24_h_percentage_change={(self.one_day_sales_24_h_percentage_change if hasattr(self, "one_day_sales_24_h_percentage_change") else None)!s}, '
                f'one_day_average_sale_price={(self.one_day_average_sale_price if hasattr(self, "one_day_average_sale_price") else None)!s}, '
                f'one_day_average_sale_price_24_h_percentage_change={(self.one_day_average_sale_price_24_h_percentage_change if hasattr(self, "one_day_average_sale_price_24_h_percentage_change") else None)!s}, '
                f'links={(self.links if hasattr(self, "links") else None)!s}, '
                f'floor_price_7_d_percentage_change={(self.floor_price_7_d_percentage_change if hasattr(self, "floor_price_7_d_percentage_change") else None)!s}, '
                f'floor_price_14_d_percentage_change={(self.floor_price_14_d_percentage_change if hasattr(self, "floor_price_14_d_percentage_change") else None)!s}, '
                f'floor_price_30_d_percentage_change={(self.floor_price_30_d_percentage_change if hasattr(self, "floor_price_30_d_percentage_change") else None)!s}, '
                f'floor_price_60_d_percentage_change={(self.floor_price_60_d_percentage_change if hasattr(self, "floor_price_60_d_percentage_change") else None)!s}, '
                f'floor_price_1_y_percentage_change={(self.floor_price_1_y_percentage_change if hasattr(self, "floor_price_1_y_percentage_change") else None)!s}, '
                f'explorers={(self.explorers if hasattr(self, "explorers") else None)!s}, '
                f'user_favorites_count={(self.user_favorites_count if hasattr(self, "user_favorites_count") else None)!s}, '
                f'ath={(self.ath if hasattr(self, "ath") else None)!s}, '
                f'ath_change_percentage={(self.ath_change_percentage if hasattr(self, "ath_change_percentage") else None)!s}, '
                f'ath_date={(self.ath_date if hasattr(self, "ath_date") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.data_2 import Data2


class Categories2(object):

    """Implementation of the 'Categories2' model.

    Attributes:
        id (float): The model property of type float.
        name (str): category name
        market_cap_1_h_change (float): category market cap 1 hour change
        slug (str): category web slug
        coins_count (float): category number of coins
        data (Data2): The model property of type Data2.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "name": 'name',
        "market_cap_1_h_change": 'market_cap_1h_change',
        "slug": 'slug',
        "coins_count": 'coins_count',
        "data": 'data'
    }

    _optionals = [
        'id',
        'name',
        'market_cap_1_h_change',
        'slug',
        'coins_count',
        'data',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 market_cap_1_h_change=APIHelper.SKIP,
                 slug=APIHelper.SKIP,
                 coins_count=APIHelper.SKIP,
                 data=APIHelper.SKIP):
        """Constructor for the Categories2 class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if market_cap_1_h_change is not APIHelper.SKIP:
            self.market_cap_1_h_change = market_cap_1_h_change 
        if slug is not APIHelper.SKIP:
            self.slug = slug 
        if coins_count is not APIHelper.SKIP:
            self.coins_count = coins_count 
        if data is not APIHelper.SKIP:
            self.data = data 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        market_cap_1_h_change = dictionary.get("market_cap_1h_change") if dictionary.get("market_cap_1h_change") else APIHelper.SKIP
        slug = dictionary.get("slug") if dictionary.get("slug") else APIHelper.SKIP
        coins_count = dictionary.get("coins_count") if dictionary.get("coins_count") else APIHelper.SKIP
        data = Data2.from_dictionary(dictionary.get('data')) if 'data' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   name,
                   market_cap_1_h_change,
                   slug,
                   coins_count,
                   data)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'market_cap_1_h_change={(self.market_cap_1_h_change if hasattr(self, "market_cap_1_h_change") else None)!r}, '
                f'slug={(self.slug if hasattr(self, "slug") else None)!r}, '
                f'coins_count={(self.coins_count if hasattr(self, "coins_count") else None)!r}, '
                f'data={(self.data if hasattr(self, "data") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'market_cap_1_h_change={(self.market_cap_1_h_change if hasattr(self, "market_cap_1_h_change") else None)!s}, '
                f'slug={(self.slug if hasattr(self, "slug") else None)!s}, '
                f'coins_count={(self.coins_count if hasattr(self, "coins_count") else None)!s}, '
                f'data={(self.data if hasattr(self, "data") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CoinIdEnum(object):

    """Implementation of the 'coin_id' enum.

    Attributes:
        BITCOIN: The enum member of type str.
        ETHEREUM: The enum member of type str.

    """
    BITCOIN = 'bitcoin'

    ETHEREUM = 'ethereum'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.types.file_wrapper import FileWrapper as CoreFileWrapper


class FileWrapper(CoreFileWrapper):
    """A wrapper to allow passing in content type for file uploads."""

    def __init__(self, file, content_type='application/octet-stream'):
        super().__init__(file, content_type)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'file={self._file_stream!r}, '
                f'content_type={self.content_type!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'file={self._file_stream!s}, '
                f'content_type={self.content_type!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class CommunityData1(object):

    """Implementation of the 'CommunityData1' model.

    coin community data

    Attributes:
        facebook_likes (float): coin facebook likes
        reddit_average_posts_48_h (float): coin reddit average posts 48h
        reddit_average_comments_48_h (float): coin reddit average comments 48h
        reddit_subscribers (float): coin reddit subscribers
        reddit_accounts_active_48_h (float): coin reddit accounts active 48h

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "facebook_likes": 'facebook_likes',
        "reddit_average_posts_48_h": 'reddit_average_posts_48h',
        "reddit_average_comments_48_h": 'reddit_average_comments_48h',
        "reddit_subscribers": 'reddit_subscribers',
        "reddit_accounts_active_48_h": 'reddit_accounts_active_48h'
    }

    _optionals = [
        'facebook_likes',
        'reddit_average_posts_48_h',
        'reddit_average_comments_48_h',
        'reddit_subscribers',
        'reddit_accounts_active_48_h',
    ]

    def __init__(self,
                 facebook_likes=APIHelper.SKIP,
                 reddit_average_posts_48_h=APIHelper.SKIP,
                 reddit_average_comments_48_h=APIHelper.SKIP,
                 reddit_subscribers=APIHelper.SKIP,
                 reddit_accounts_active_48_h=APIHelper.SKIP):
        """Constructor for the CommunityData1 class"""

        # Initialize members of the class
        if facebook_likes is not APIHelper.SKIP:
            self.facebook_likes = facebook_likes 
        if reddit_average_posts_48_h is not APIHelper.SKIP:
            self.reddit_average_posts_48_h = reddit_average_posts_48_h 
        if reddit_average_comments_48_h is not APIHelper.SKIP:
            self.reddit_average_comments_48_h = reddit_average_comments_48_h 
        if reddit_subscribers is not APIHelper.SKIP:
            self.reddit_subscribers = reddit_subscribers 
        if reddit_accounts_active_48_h is not APIHelper.SKIP:
            self.reddit_accounts_active_48_h = reddit_accounts_active_48_h 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        facebook_likes = dictionary.get("facebook_likes") if dictionary.get("facebook_likes") else APIHelper.SKIP
        reddit_average_posts_48_h = dictionary.get("reddit_average_posts_48h") if dictionary.get("reddit_average_posts_48h") else APIHelper.SKIP
        reddit_average_comments_48_h = dictionary.get("reddit_average_comments_48h") if dictionary.get("reddit_average_comments_48h") else APIHelper.SKIP
        reddit_subscribers = dictionary.get("reddit_subscribers") if dictionary.get("reddit_subscribers") else APIHelper.SKIP
        reddit_accounts_active_48_h = dictionary.get("reddit_accounts_active_48h") if dictionary.get("reddit_accounts_active_48h") else APIHelper.SKIP
        # Return an object of this model
        return cls(facebook_likes,
                   reddit_average_posts_48_h,
                   reddit_average_comments_48_h,
                   reddit_subscribers,
                   reddit_accounts_active_48_h)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'facebook_likes={(self.facebook_likes if hasattr(self, "facebook_likes") else None)!r}, '
                f'reddit_average_posts_48_h={(self.reddit_average_posts_48_h if hasattr(self, "reddit_average_posts_48_h") else None)!r}, '
                f'reddit_average_comments_48_h={(self.reddit_average_comments_48_h if hasattr(self, "reddit_average_comments_48_h") else None)!r}, '
                f'reddit_subscribers={(self.reddit_subscribers if hasattr(self, "reddit_subscribers") else None)!r}, '
                f'reddit_accounts_active_48_h={(self.reddit_accounts_active_48_h if hasattr(self, "reddit_accounts_active_48_h") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'facebook_likes={(self.facebook_likes if hasattr(self, "facebook_likes") else None)!s}, '
                f'reddit_average_posts_48_h={(self.reddit_average_posts_48_h if hasattr(self, "reddit_average_posts_48_h") else None)!s}, '
                f'reddit_average_comments_48_h={(self.reddit_average_comments_48_h if hasattr(self, "reddit_average_comments_48_h") else None)!s}, '
                f'reddit_subscribers={(self.reddit_subscribers if hasattr(self, "reddit_subscribers") else None)!s}, '
                f'reddit_accounts_active_48_h={(self.reddit_accounts_active_48_h if hasattr(self, "reddit_accounts_active_48_h") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.configuration import Server
from coingeckopublicapiv3.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from coingeckopublicapiv3.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.or_auth_group import Or
from coingeckopublicapiv3.models.mglobal import Global
from coingeckopublicapiv3.models.global_de_fi import GlobalDeFi


class GlobalController(BaseController):

    """A Controller to access Endpoints in the coingeckopublicapiv3 API."""
    def __init__(self, config):
        super(GlobalController, self).__init__(config)

    def crypto_global(self):
        """Does a GET request to /global.

        This endpoint allows you **query cryptocurrency global data including
        active cryptocurrencies, markets, total crypto market cap and etc**

        Returns:
            Global: Response from the API. Get cryptocurrency global data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/global')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Global.from_dictionary)
        ).execute()

    def global_de_fi(self):
        """Does a GET request to /global/decentralized_finance_defi.

        This endpoint allows you **query top 100 cryptocurrency global
        decentralized finance (DeFi) data including DeFi market cap, trading
        volume**

        Returns:
            GlobalDeFi: Response from the API. Get cryptocurrency global
                decentralized finance (defi) data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/global/decentralized_finance_defi')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GlobalDeFi.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IncludeTickersEnum(object):

    """Implementation of the 'include_tickers' enum.

    Attributes:
        ALL: The enum member of type str.
        UNEXPIRED: The enum member of type str.

    """
    ALL = 'all'

    UNEXPIRED = 'unexpired'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class DerivativesTickersList(object):

    """Implementation of the 'DerivativesTickersList' model.

    Attributes:
        market (str): derivative market name
        symbol (str): derivative ticker symbol
        index_id (str): derivative underlying asset
        price (str): derivative ticker price
        price_percentage_change_24_h (float): derivative ticker price
            percentage change in 24 hours
        contract_type (str): derivative contract type
        index (float): derivative underlying asset price
        basis (float): difference of derivative price and index price
        spread (float): derivative bid ask spread
        funding_rate (float): derivative funding rate
        open_interest (float): derivative open interest
        volume_24_h (float): derivative volume in 24 hours
        last_traded_at (float): derivative last updated time
        expired_at (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "market": 'market',
        "symbol": 'symbol',
        "index_id": 'index_id',
        "price": 'price',
        "price_percentage_change_24_h": 'price_percentage_change_24h',
        "contract_type": 'contract_type',
        "index": 'index',
        "basis": 'basis',
        "spread": 'spread',
        "funding_rate": 'funding_rate',
        "open_interest": 'open_interest',
        "volume_24_h": 'volume_24h',
        "last_traded_at": 'last_traded_at',
        "expired_at": 'expired_at'
    }

    _optionals = [
        'market',
        'symbol',
        'index_id',
        'price',
        'price_percentage_change_24_h',
        'contract_type',
        'index',
        'basis',
        'spread',
        'funding_rate',
        'open_interest',
        'volume_24_h',
        'last_traded_at',
        'expired_at',
    ]

    _nullables = [
        'expired_at',
    ]

    def __init__(self,
                 market=APIHelper.SKIP,
                 symbol=APIHelper.SKIP,
                 index_id=APIHelper.SKIP,
                 price=APIHelper.SKIP,
                 price_percentage_change_24_h=APIHelper.SKIP,
                 contract_type=APIHelper.SKIP,
                 index=APIHelper.SKIP,
                 basis=APIHelper.SKIP,
                 spread=APIHelper.SKIP,
                 funding_rate=APIHelper.SKIP,
                 open_interest=APIHelper.SKIP,
                 volume_24_h=APIHelper.SKIP,
                 last_traded_at=APIHelper.SKIP,
                 expired_at=APIHelper.SKIP):
        """Constructor for the DerivativesTickersList class"""

        # Initialize members of the class
        if market is not APIHelper.SKIP:
            self.market = market 
        if symbol is not APIHelper.SKIP:
            self.symbol = symbol 
        if index_id is not APIHelper.SKIP:
            self.index_id = index_id 
        if price is not APIHelper.SKIP:
            self.price = price 
        if price_percentage_change_24_h is not APIHelper.SKIP:
            self.price_percentage_change_24_h = price_percentage_change_24_h 
        if contract_type is not APIHelper.SKIP:
            self.contract_type = contract_type 
        if index is not APIHelper.SKIP:
            self.index = index 
        if basis is not APIHelper.SKIP:
            self.basis = basis 
        if spread is not APIHelper.SKIP:
            self.spread = spread 
        if funding_rate is not APIHelper.SKIP:
            self.funding_rate = funding_rate 
        if open_interest is not APIHelper.SKIP:
            self.open_interest = open_interest 
        if volume_24_h is not APIHelper.SKIP:
            self.volume_24_h = volume_24_h 
        if last_traded_at is not APIHelper.SKIP:
            self.last_traded_at = last_traded_at 
        if expired_at is not APIHelper.SKIP:
            self.expired_at = expired_at 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        market = dictionary.get("market") if dictionary.get("market") else APIHelper.SKIP
        symbol = dictionary.get("symbol") if dictionary.get("symbol") else APIHelper.SKIP
        index_id = dictionary.get("index_id") if dictionary.get("index_id") else APIHelper.SKIP
        price = dictionary.get("price") if dictionary.get("price") else APIHelper.SKIP
        price_percentage_change_24_h = dictionary.get("price_percentage_change_24h") if dictionary.get("price_percentage_change_24h") else APIHelper.SKIP
        contract_type = dictionary.get("contract_type") if dictionary.get("contract_type") else APIHelper.SKIP
        index = dictionary.get("index") if dictionary.get("index") else APIHelper.SKIP
        basis = dictionary.get("basis") if dictionary.get("basis") else APIHelper.SKIP
        spread = dictionary.get("spread") if dictionary.get("spread") else APIHelper.SKIP
        funding_rate = dictionary.get("funding_rate") if dictionary.get("funding_rate") else APIHelper.SKIP
        open_interest = dictionary.get("open_interest") if dictionary.get("open_interest") else APIHelper.SKIP
        volume_24_h = dictionary.get("volume_24h") if dictionary.get("volume_24h") else APIHelper.SKIP
        last_traded_at = dictionary.get("last_traded_at") if dictionary.get("last_traded_at") else APIHelper.SKIP
        expired_at = dictionary.get("expired_at") if "expired_at" in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(market,
                   symbol,
                   index_id,
                   price,
                   price_percentage_change_24_h,
                   contract_type,
                   index,
                   basis,
                   spread,
                   funding_rate,
                   open_interest,
                   volume_24_h,
                   last_traded_at,
                   expired_at)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'market={(self.market if hasattr(self, "market") else None)!r}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!r}, '
                f'index_id={(self.index_id if hasattr(self, "index_id") else None)!r}, '
                f'price={(self.price if hasattr(self, "price") else None)!r}, '
                f'price_percentage_change_24_h={(self.price_percentage_change_24_h if hasattr(self, "price_percentage_change_24_h") else None)!r}, '
                f'contract_type={(self.contract_type if hasattr(self, "contract_type") else None)!r}, '
                f'index={(self.index if hasattr(self, "index") else None)!r}, '
                f'basis={(self.basis if hasattr(self, "basis") else None)!r}, '
                f'spread={(self.spread if hasattr(self, "spread") else None)!r}, '
                f'funding_rate={(self.funding_rate if hasattr(self, "funding_rate") else None)!r}, '
                f'open_interest={(self.open_interest if hasattr(self, "open_interest") else None)!r}, '
                f'volume_24_h={(self.volume_24_h if hasattr(self, "volume_24_h") else None)!r}, '
                f'last_traded_at={(self.last_traded_at if hasattr(self, "last_traded_at") else None)!r}, '
                f'expired_at={(self.expired_at if hasattr(self, "expired_at") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'market={(self.market if hasattr(self, "market") else None)!s}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!s}, '
                f'index_id={(self.index_id if hasattr(self, "index_id") else None)!s}, '
                f'price={(self.price if hasattr(self, "price") else None)!s}, '
                f'price_percentage_change_24_h={(self.price_percentage_change_24_h if hasattr(self, "price_percentage_change_24_h") else None)!s}, '
                f'contract_type={(self.contract_type if hasattr(self, "contract_type") else None)!s}, '
                f'index={(self.index if hasattr(self, "index") else None)!s}, '
                f'basis={(self.basis if hasattr(self, "basis") else None)!s}, '
                f'spread={(self.spread if hasattr(self, "spread") else None)!s}, '
                f'funding_rate={(self.funding_rate if hasattr(self, "funding_rate") else None)!s}, '
                f'open_interest={(self.open_interest if hasattr(self, "open_interest") else None)!s}, '
                f'volume_24_h={(self.volume_24_h if hasattr(self, "volume_24_h") else None)!s}, '
                f'last_traded_at={(self.last_traded_at if hasattr(self, "last_traded_at") else None)!s}, '
                f'expired_at={(self.expired_at if hasattr(self, "expired_at") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.token import Token


class TokenLists(object):

    """Implementation of the 'TokenLists' model.

    Attributes:
        name (str): The model property of type str.
        logo_uri (str): The model property of type str.
        keywords (List[str]): The model property of type List[str].
        timestamp (datetime): The model property of type datetime.
        tokens (List[Token]): The model property of type List[Token].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "logo_uri": 'logoURI',
        "keywords": 'keywords',
        "timestamp": 'timestamp',
        "tokens": 'tokens'
    }

    _optionals = [
        'name',
        'logo_uri',
        'keywords',
        'timestamp',
        'tokens',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 logo_uri=APIHelper.SKIP,
                 keywords=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP,
                 tokens=APIHelper.SKIP):
        """Constructor for the TokenLists class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if logo_uri is not APIHelper.SKIP:
            self.logo_uri = logo_uri 
        if keywords is not APIHelper.SKIP:
            self.keywords = keywords 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = APIHelper.apply_datetime_converter(timestamp, APIHelper.RFC3339DateTime) if timestamp else None 
        if tokens is not APIHelper.SKIP:
            self.tokens = tokens 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        logo_uri = dictionary.get("logoURI") if dictionary.get("logoURI") else APIHelper.SKIP
        keywords = dictionary.get("keywords") if dictionary.get("keywords") else APIHelper.SKIP
        timestamp = APIHelper.RFC3339DateTime.from_value(dictionary.get("timestamp")).datetime if dictionary.get("timestamp") else APIHelper.SKIP
        tokens = None
        if dictionary.get('tokens') is not None:
            tokens = [Token.from_dictionary(x) for x in dictionary.get('tokens')]
        else:
            tokens = APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   logo_uri,
                   keywords,
                   timestamp,
                   tokens)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'logo_uri={(self.logo_uri if hasattr(self, "logo_uri") else None)!r}, '
                f'keywords={(self.keywords if hasattr(self, "keywords") else None)!r}, '
                f'timestamp={(self.timestamp if hasattr(self, "timestamp") else None)!r}, '
                f'tokens={(self.tokens if hasattr(self, "tokens") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'logo_uri={(self.logo_uri if hasattr(self, "logo_uri") else None)!s}, '
                f'keywords={(self.keywords if hasattr(self, "keywords") else None)!s}, '
                f'timestamp={(self.timestamp if hasattr(self, "timestamp") else None)!s}, '
                f'tokens={(self.tokens if hasattr(self, "tokens") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order2Enum(object):

    """Implementation of the 'order2' enum.

    Attributes:
        MARKET_CAP_DESC: The enum member of type str.
        MARKET_CAP_ASC: The enum member of type str.
        NAME_DESC: The enum member of type str.
        NAME_ASC: The enum member of type str.
        MARKET_CAP_CHANGE_24H_DESC: The enum member of type str.
        MARKET_CAP_CHANGE_24H_ASC: The enum member of type str.

    """
    MARKET_CAP_DESC = 'market_cap_desc'

    MARKET_CAP_ASC = 'market_cap_asc'

    NAME_DESC = 'name_desc'

    NAME_ASC = 'name_asc'

    MARKET_CAP_CHANGE_24H_DESC = 'market_cap_change_24h_desc'

    MARKET_CAP_CHANGE_24H_ASC = 'market_cap_change_24h_asc'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.configuration import Server
from coingeckopublicapiv3.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from coingeckopublicapiv3.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.or_auth_group import Or
from coingeckopublicapiv3.models.derivatives_tickers_list import DerivativesTickersList
from coingeckopublicapiv3.models.derivatives_exchanges import DerivativesExchanges
from coingeckopublicapiv3.models.derivatives_exchanges_id import DerivativesExchangesID
from coingeckopublicapiv3.models.derivatives_exchanges_list import DerivativesExchangesList


class DerivativesController(BaseController):

    """A Controller to access Endpoints in the coingeckopublicapiv3 API."""
    def __init__(self, config):
        super(DerivativesController, self).__init__(config)

    def derivatives_tickers(self):
        """Does a GET request to /derivatives.

        This endpoint allows you to **query all the tickers from derivatives
        exchanges on CoinGecko**

        Returns:
            DerivativesTickersList: Response from the API. List all derivative
                tickers

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/derivatives')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(DerivativesTickersList.from_dictionary)
        ).execute()

    def derivatives_exchanges(self,
                              order=None,
                              per_page=None,
                              page=None):
        """Does a GET request to /derivatives/exchanges.

        This endpoint allows you to **query all the derivatives exchanges with
        related data (ID, name, open interest, ...) on CoinGecko**

        Args:
            order (Order4Enum, optional): use this to sort the order of
                responses, default: open_interest_btc_desc
            per_page (int, optional): total results per page
            page (int, optional): page through results, default: 1

        Returns:
            DerivativesExchanges: Response from the API. List all derivative
                exchanges

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/derivatives/exchanges')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('order')
                         .value(order))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(DerivativesExchanges.from_dictionary)
        ).execute()

    def derivatives_exchanges_id(self,
                                 id,
                                 include_tickers=None):
        """Does a GET request to /derivatives/exchanges/{id}.

        This endpoint allows you to **query the derivatives exchange’s related
        data (ID, name, open interest, ...) based on the exchanges’ ID**

        Args:
            id (str): derivative exchange ID <br> *refers to
                [`/derivatives/exchanges/list`](/reference/derivatives-exchange
                s-list).
            include_tickers (IncludeTickersEnum, optional): include tickers
                data

        Returns:
            DerivativesExchangesID: Response from the API. Get derivative
                exchange data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/derivatives/exchanges/{id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('include_tickers')
                         .value(include_tickers))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(DerivativesExchangesID.from_dictionary)
        ).execute()

    def derivatives_exchanges_list(self):
        """Does a GET request to /derivatives/exchanges/list.

        This endpoint allows you to **query all the derivatives exchanges with
        ID and name on CoinGecko**

        Returns:
            DerivativesExchangesList: Response from the API. List all
                derivative exchanges name and identifier

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/derivatives/exchanges/list')
            .http_method(HttpMethodEnum.GET)
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(DerivativesExchangesList.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.data_4 import Data4


class GlobalDeFi(object):

    """Implementation of the 'GlobalDeFi' model.

    Attributes:
        data (Data4): The model property of type Data4.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "data": 'data'
    }

    _optionals = [
        'data',
    ]

    def __init__(self,
                 data=APIHelper.SKIP):
        """Constructor for the GlobalDeFi class"""

        # Initialize members of the class
        if data is not APIHelper.SKIP:
            self.data = data 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        data = Data4.from_dictionary(dictionary.get('data')) if 'data' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(data)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'data={(self.data if hasattr(self, "data") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'data={(self.data if hasattr(self, "data") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.configurations.global_configuration import GlobalConfiguration
from apimatic_core.decorators.lazy_property import LazyProperty
from coingeckopublicapiv3.configuration import Configuration
from coingeckopublicapiv3.controllers.base_controller import BaseController
from coingeckopublicapiv3.configuration import Environment
from coingeckopublicapiv3.http.auth.api_key_auth import ApiKeyAuth
from coingeckopublicapiv3.http.auth.api_key_query_param import ApiKeyQueryParam
from coingeckopublicapiv3.controllers.ping_controller import PingController
from coingeckopublicapiv3.controllers.simple_controller import SimpleController
from coingeckopublicapiv3.controllers.coins_controller import CoinsController
from coingeckopublicapiv3.controllers.contract_controller\
    import ContractController
from coingeckopublicapiv3.controllers.asset_platforms_controller\
    import AssetPlatformsController
from coingeckopublicapiv3.controllers.categories_controller\
    import CategoriesController
from coingeckopublicapiv3.controllers.exchanges_controller\
    import ExchangesController
from coingeckopublicapiv3.controllers.derivatives_controller\
    import DerivativesController
from coingeckopublicapiv3.controllers.nf_ts_beta_controller\
    import NFTsBetaController
from coingeckopublicapiv3.controllers.exchange_rates_controller\
    import ExchangeRatesController
from coingeckopublicapiv3.controllers.search_controller import SearchController
from coingeckopublicapiv3.controllers.trending_controller\
    import TrendingController
from coingeckopublicapiv3.controllers.global_controller import GlobalController
from coingeckopublicapiv3.controllers.companies_beta_controller\
    import CompaniesBetaController


class Coingeckopublicapiv3Client(object):
    @LazyProperty
    def ping(self):
        return PingController(self.global_configuration)

    @LazyProperty
    def simple(self):
        return SimpleController(self.global_configuration)

    @LazyProperty
    def coins(self):
        return CoinsController(self.global_configuration)

    @LazyProperty
    def contract(self):
        return ContractController(self.global_configuration)

    @LazyProperty
    def asset_platforms(self):
        return AssetPlatformsController(self.global_configuration)

    @LazyProperty
    def categories(self):
        return CategoriesController(self.global_configuration)

    @LazyProperty
    def exchanges(self):
        return ExchangesController(self.global_configuration)

    @LazyProperty
    def derivatives(self):
        return DerivativesController(self.global_configuration)

    @LazyProperty
    def nf_ts_beta(self):
        return NFTsBetaController(self.global_configuration)

    @LazyProperty
    def exchange_rates(self):
        return ExchangeRatesController(self.global_configuration)

    @LazyProperty
    def search(self):
        return SearchController(self.global_configuration)

    @LazyProperty
    def trending(self):
        return TrendingController(self.global_configuration)

    @LazyProperty
    def mglobal(self):
        return GlobalController(self.global_configuration)

    @LazyProperty
    def companies_beta(self):
        return CompaniesBetaController(self.global_configuration)

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, http_call_back=None,
                 timeout=60, max_retries=0, backoff_factor=2,
                 retry_statuses=None, retry_methods=None,
                 environment=Environment.PRODUCTION,
                 api_key_auth_credentials=None,
                 api_key_query_param_credentials=None, config=None):
        self.config = config or Configuration(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout,
            max_retries=max_retries, backoff_factor=backoff_factor,
            retry_statuses=retry_statuses, retry_methods=retry_methods,
            environment=environment,
            api_key_auth_credentials=api_key_auth_credentials,
            api_key_query_param_credentials=api_key_query_param_credentials)

        self.global_configuration = GlobalConfiguration(self.config)\
            .global_errors(BaseController.global_errors())\
            .base_uri_executor(self.config.get_base_uri)\
            .user_agent(BaseController.user_agent(), BaseController.user_agent_parameters())

        self.auth_managers = {key: None for key in ['apiKeyAuth',
                                                    'apiKeyQueryParam']}
        self.auth_managers['apiKeyAuth'] = ApiKeyAuth(
            self.config.api_key_auth_credentials)
        self.auth_managers['apiKeyQueryParam'] = ApiKeyQueryParam(
            self.config.api_key_query_param_credentials)
        self.global_configuration = self.global_configuration.auth_managers(self.auth_managers)




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.rates import Rates


class ExchangeRates(object):

    """Implementation of the 'ExchangeRates' model.

    Attributes:
        rates (Dict[str, Rates]): The model property of type Dict[str, Rates].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "rates": 'rates'
    }

    _optionals = [
        'rates',
    ]

    def __init__(self,
                 rates=APIHelper.SKIP):
        """Constructor for the ExchangeRates class"""

        # Initialize members of the class
        if rates is not APIHelper.SKIP:
            self.rates = rates 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        rates = Rates.from_dictionary(dictionary.get('rates')) if 'rates' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(rates)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'rates={(self.rates if hasattr(self, "rates") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'rates={(self.rates if hasattr(self, "rates") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StatusEnum(object):

    """Implementation of the 'status' enum.

    Attributes:
        ACTIVE: The enum member of type str.
        INACTIVE: The enum member of type str.

    """
    ACTIVE = 'active'

    INACTIVE = 'inactive'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.image_2 import Image2


class AssetPlatform(object):

    """Implementation of the 'AssetPlatform' model.

    Attributes:
        id (str): asset platform ID
        chain_identifier (float): chainlist's chain ID
        name (str): chain name
        shortname (str): chain shortname
        native_coin_id (str): chain native coin ID
        image (Image2): image of the asset platform

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "chain_identifier": 'chain_identifier',
        "name": 'name',
        "shortname": 'shortname',
        "native_coin_id": 'native_coin_id',
        "image": 'image'
    }

    _optionals = [
        'id',
        'chain_identifier',
        'name',
        'shortname',
        'native_coin_id',
        'image',
    ]

    _nullables = [
        'chain_identifier',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 chain_identifier=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 shortname=APIHelper.SKIP,
                 native_coin_id=APIHelper.SKIP,
                 image=APIHelper.SKIP):
        """Constructor for the AssetPlatform class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if chain_identifier is not APIHelper.SKIP:
            self.chain_identifier = chain_identifier 
        if name is not APIHelper.SKIP:
            self.name = name 
        if shortname is not APIHelper.SKIP:
            self.shortname = shortname 
        if native_coin_id is not APIHelper.SKIP:
            self.native_coin_id = native_coin_id 
        if image is not APIHelper.SKIP:
            self.image = image 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        chain_identifier = dictionary.get("chain_identifier") if "chain_identifier" in dictionary.keys() else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        shortname = dictionary.get("shortname") if dictionary.get("shortname") else APIHelper.SKIP
        native_coin_id = dictionary.get("native_coin_id") if dictionary.get("native_coin_id") else APIHelper.SKIP
        image = Image2.from_dictionary(dictionary.get('image')) if 'image' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   chain_identifier,
                   name,
                   shortname,
                   native_coin_id,
                   image)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'chain_identifier={(self.chain_identifier if hasattr(self, "chain_identifier") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'shortname={(self.shortname if hasattr(self, "shortname") else None)!r}, '
                f'native_coin_id={(self.native_coin_id if hasattr(self, "native_coin_id") else None)!r}, '
                f'image={(self.image if hasattr(self, "image") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'chain_identifier={(self.chain_identifier if hasattr(self, "chain_identifier") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'shortname={(self.shortname if hasattr(self, "shortname") else None)!s}, '
                f'native_coin_id={(self.native_coin_id if hasattr(self, "native_coin_id") else None)!s}, '
                f'image={(self.image if hasattr(self, "image") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.market_cap_change_percentage_24_h import MarketCapChangePercentage24h


class Data2(object):

    """Implementation of the 'Data2' model.

    Attributes:
        market_cap (float): category market cap
        market_cap_btc (float): category market cap in btc
        total_volume (float): category total volume
        total_volume_btc (float): category total volume in btc
        market_cap_change_percentage_24_h (MarketCapChangePercentage24h):
            category market cap change percentage in 24 hours
        sparkline (str): category sparkline image url

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "market_cap": 'market_cap',
        "market_cap_btc": 'market_cap_btc',
        "total_volume": 'total_volume',
        "total_volume_btc": 'total_volume_btc',
        "market_cap_change_percentage_24_h": 'market_cap_change_percentage_24h',
        "sparkline": 'sparkline'
    }

    _optionals = [
        'market_cap',
        'market_cap_btc',
        'total_volume',
        'total_volume_btc',
        'market_cap_change_percentage_24_h',
        'sparkline',
    ]

    def __init__(self,
                 market_cap=APIHelper.SKIP,
                 market_cap_btc=APIHelper.SKIP,
                 total_volume=APIHelper.SKIP,
                 total_volume_btc=APIHelper.SKIP,
                 market_cap_change_percentage_24_h=APIHelper.SKIP,
                 sparkline=APIHelper.SKIP):
        """Constructor for the Data2 class"""

        # Initialize members of the class
        if market_cap is not APIHelper.SKIP:
            self.market_cap = market_cap 
        if market_cap_btc is not APIHelper.SKIP:
            self.market_cap_btc = market_cap_btc 
        if total_volume is not APIHelper.SKIP:
            self.total_volume = total_volume 
        if total_volume_btc is not APIHelper.SKIP:
            self.total_volume_btc = total_volume_btc 
        if market_cap_change_percentage_24_h is not APIHelper.SKIP:
            self.market_cap_change_percentage_24_h = market_cap_change_percentage_24_h 
        if sparkline is not APIHelper.SKIP:
            self.sparkline = sparkline 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        market_cap = dictionary.get("market_cap") if dictionary.get("market_cap") else APIHelper.SKIP
        market_cap_btc = dictionary.get("market_cap_btc") if dictionary.get("market_cap_btc") else APIHelper.SKIP
        total_volume = dictionary.get("total_volume") if dictionary.get("total_volume") else APIHelper.SKIP
        total_volume_btc = dictionary.get("total_volume_btc") if dictionary.get("total_volume_btc") else APIHelper.SKIP
        market_cap_change_percentage_24_h = MarketCapChangePercentage24h.from_dictionary(dictionary.get('market_cap_change_percentage_24h')) if 'market_cap_change_percentage_24h' in dictionary.keys() else APIHelper.SKIP
        sparkline = dictionary.get("sparkline") if dictionary.get("sparkline") else APIHelper.SKIP
        # Return an object of this model
        return cls(market_cap,
                   market_cap_btc,
                   total_volume,
                   total_volume_btc,
                   market_cap_change_percentage_24_h,
                   sparkline)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!r}, '
                f'market_cap_btc={(self.market_cap_btc if hasattr(self, "market_cap_btc") else None)!r}, '
                f'total_volume={(self.total_volume if hasattr(self, "total_volume") else None)!r}, '
                f'total_volume_btc={(self.total_volume_btc if hasattr(self, "total_volume_btc") else None)!r}, '
                f'market_cap_change_percentage_24_h={(self.market_cap_change_percentage_24_h if hasattr(self, "market_cap_change_percentage_24_h") else None)!r}, '
                f'sparkline={(self.sparkline if hasattr(self, "sparkline") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'market_cap={(self.market_cap if hasattr(self, "market_cap") else None)!s}, '
                f'market_cap_btc={(self.market_cap_btc if hasattr(self, "market_cap_btc") else None)!s}, '
                f'total_volume={(self.total_volume if hasattr(self, "total_volume") else None)!s}, '
                f'total_volume_btc={(self.total_volume_btc if hasattr(self, "total_volume_btc") else None)!s}, '
                f'market_cap_change_percentage_24_h={(self.market_cap_change_percentage_24_h if hasattr(self, "market_cap_change_percentage_24_h") else None)!s}, '
                f'sparkline={(self.sparkline if hasattr(self, "sparkline") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.configuration import Server
from coingeckopublicapiv3.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from coingeckopublicapiv3.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.or_auth_group import Or
from coingeckopublicapiv3.models.coins_list import CoinsList
from coingeckopublicapiv3.models.coins_markets import CoinsMarkets
from coingeckopublicapiv3.models.coins_data_base import CoinsDataBase
from coingeckopublicapiv3.models.coins_tickers import CoinsTickers
from coingeckopublicapiv3.models.coins_historical_data import CoinsHistoricalData
from coingeckopublicapiv3.models.coins_market_chart import CoinsMarketChart
from coingeckopublicapiv3.models.coins_market_chart_range import CoinsMarketChartRange


class CoinsController(BaseController):

    """A Controller to access Endpoints in the coingeckopublicapiv3 API."""
    def __init__(self, config):
        super(CoinsController, self).__init__(config)

    def coins_list(self,
                   include_platform=None):
        """Does a GET request to /coins/list.

        This endpoint allows you to **query all the supported coins on
        CoinGecko with coins ID, name and symbol**

        Args:
            include_platform (bool, optional): include platform and token's
                contract addresses, default: false

        Returns:
            List[CoinsList]: Response from the API. List all coins with ID,
                name, and symbol

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/list')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('include_platform')
                         .value(include_platform))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CoinsList.from_dictionary)
        ).execute()

    def coins_markets(self,
                      vs_currency,
                      ids=None,
                      names=None,
                      symbols=None,
                      include_tokens=None,
                      category=None,
                      order=None,
                      per_page=None,
                      page=None,
                      sparkline=None,
                      price_change_percentage=None,
                      locale=None,
                      precision=None):
        """Does a GET request to /coins/markets.

        This endpoint allows you to **query all the supported coins with
        price, market cap, volume and market related data**

        Args:
            vs_currency (str): target currency of coins and market data <br>
                *refers to
                [`/simple/supported_vs_currencies`](/reference/simple-supported
                -currencies).
            ids (str, optional): coins' IDs, comma-separated if querying more
                than 1 coin. <br> *refers to
                [`/coins/list`](/reference/coins-list).
            names (str, optional): coins' names, comma-separated if querying
                more than 1 coin.
            symbols (str, optional): coins' symbols, comma-separated if
                querying more than 1 coin.
            include_tokens (IncludeTokensEnum, optional): for `symbols`
                lookups, specify `all` to include all matching tokens <br>
                Default `top` returns top-ranked tokens (by market cap or
                volume)
            category (str, optional): filter based on coins' category <br>
                *refers to
                [`/coins/categories/list`](/reference/coins-categories-list).
            order (OrderEnum, optional): sort result by field, default:
                market_cap_desc
            per_page (int, optional): total results per page, default: 100
                <br> Valid values: 1...250
            page (int, optional): page through results, default: 1
            sparkline (bool, optional): include sparkline 7 days data,
                default: false
            price_change_percentage (str, optional): include price change
                percentage timeframe, comma-separated if query more than 1
                price change percentage timeframe <br> Valid values: 1h, 24h,
                7d, 14d, 30d, 200d, 1y
            locale (LocaleEnum, optional): language background, default: en
            precision (PrecisionEnum, optional): decimal place for currency
                price value

        Returns:
            CoinsMarkets: Response from the API. List all coins with market
                data

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/markets')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('vs_currency')
                         .value(vs_currency))
            .query_param(Parameter()
                         .key('ids')
                         .value(ids))
            .query_param(Parameter()
                         .key('names')
                         .value(names))
            .query_param(Parameter()
                         .key('symbols')
                         .value(symbols))
            .query_param(Parameter()
                         .key('include_tokens')
                         .value(include_tokens))
            .query_param(Parameter()
                         .key('category')
                         .value(category))
            .query_param(Parameter()
                         .key('order')
                         .value(order))
            .query_param(Parameter()
                         .key('per_page')
                         .value(per_page))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('sparkline')
                         .value(sparkline))
            .query_param(Parameter()
                         .key('price_change_percentage')
                         .value(price_change_percentage))
            .query_param(Parameter()
                         .key('locale')
                         .value(locale))
            .query_param(Parameter()
                         .key('precision')
                         .value(precision))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CoinsMarkets.from_dictionary)
        ).execute()

    def coins_id(self,
                 id,
                 localization=None,
                 tickers=None,
                 market_data=None,
                 community_data=None,
                 developer_data=None,
                 sparkline=None,
                 dex_pair_format=None):
        """Does a GET request to /coins/{id}.

        This endpoint allows you to **query all the metadata (image, websites,
        socials, description, contract address, etc.) and market data (price,
        ATH, exchange tickers, etc.) of a coin from the CoinGecko coin page
        based on a particular coin ID**

        Args:
            id (str): coin ID <br> *refers to
                [`/coins/list`](/reference/coins-list).
            localization (bool, optional): include all the localized languages
                in the response, default: true
            tickers (bool, optional): include tickers data, default: true
            market_data (bool, optional): include market data, default: true
            community_data (bool, optional): include community data, default:
                true
            developer_data (bool, optional): include developer data, default:
                true
            sparkline (bool, optional): include sparkline 7 days data,
                default: false
            dex_pair_format (DexPairFormatEnum, optional): set to `symbol` to
                display DEX pair base and target as symbols, default:
                `contract_address`

        Returns:
            CoinsDataBase: Response from the API. Get current data for a coin

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/{id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('localization')
                         .value(localization))
            .query_param(Parameter()
                         .key('tickers')
                         .value(tickers))
            .query_param(Parameter()
                         .key('market_data')
                         .value(market_data))
            .query_param(Parameter()
                         .key('community_data')
                         .value(community_data))
            .query_param(Parameter()
                         .key('developer_data')
                         .value(developer_data))
            .query_param(Parameter()
                         .key('sparkline')
                         .value(sparkline))
            .query_param(Parameter()
                         .key('dex_pair_format')
                         .value(dex_pair_format))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CoinsDataBase.from_dictionary)
        ).execute()

    def coins_id_tickers(self,
                         id,
                         exchange_ids=None,
                         include_exchange_logo=None,
                         page=None,
                         order=None,
                         depth=None,
                         dex_pair_format=None):
        """Does a GET request to /coins/{id}/tickers.

        This endpoint allows you to **query the coin tickers on both
        centralized exchange (CEX) and decentralized exchange (DEX) based on a
        particular coin ID**

        Args:
            id (str): coin ID <br> *refers to
                [`/coins/list`](/reference/coins-list).
            exchange_ids (str, optional): exchange ID <br> *refers to
                [`/exchanges/list`](/reference/exchanges-list).
            include_exchange_logo (bool, optional): include exchange logo,
                default: false
            page (int, optional): page through results
            order (Order1Enum, optional): use this to sort the order of
                responses, default: trust_score_desc
            depth (bool, optional): include 2% orderbook depth, ie.
                `cost_to_move_up_usd` and `cost_to_move_down_usd` <br>
                Default: false
            dex_pair_format (DexPairFormatEnum, optional): set to `symbol` to
                display DEX pair base and target as symbols, default:
                `contract_address`

        Returns:
            CoinsTickers: Response from the API. Get coin tickers

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/{id}/tickers')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('exchange_ids')
                         .value(exchange_ids))
            .query_param(Parameter()
                         .key('include_exchange_logo')
                         .value(include_exchange_logo))
            .query_param(Parameter()
                         .key('page')
                         .value(page))
            .query_param(Parameter()
                         .key('order')
                         .value(order))
            .query_param(Parameter()
                         .key('depth')
                         .value(depth))
            .query_param(Parameter()
                         .key('dex_pair_format')
                         .value(dex_pair_format))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CoinsTickers.from_dictionary)
        ).execute()

    def coins_id_history(self,
                         id,
                         date,
                         localization=None):
        """Does a GET request to /coins/{id}/history.

        This endpoint allows you to **query the historical data (price, market
        cap, 24hrs volume, ...) at a given date for a coin based on a
        particular coin ID**

        Args:
            id (str): coin ID <br> *refers to
                [`/coins/list`](/reference/coins-list).
            date (str): the date of data snapshot <br> Format: `dd-mm-yyyy`
            localization (bool, optional): include all the localized languages
                in response, default: true

        Returns:
            CoinsHistoricalData: Response from the API. Get historical data
                (name, price, market, stats) at a given date for a coin

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/{id}/history')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('date')
                         .value(date))
            .query_param(Parameter()
                         .key('localization')
                         .value(localization))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CoinsHistoricalData.from_dictionary)
        ).execute()

    def coins_id_market_chart(self,
                              id,
                              vs_currency,
                              days,
                              interval=None,
                              precision=None):
        """Does a GET request to /coins/{id}/market_chart.

        This endpoint allows you to **get the historical chart data of a coin
        including time in UNIX, price, market cap and 24hr volume based on
        particular coin ID**

        Args:
            id (str): coin ID <br> *refers to
                [`/coins/list`](/reference/coins-list).
            vs_currency (str): target currency of market data <br> *refers to
                [`/simple/supported_vs_currencies`](/reference/simple-supported
                -currencies).
            days (str): data up to number of days ago <br> You may use any
                integer for number of days
            interval (IntervalEnum, optional): data interval, leave empty for
                auto granularity Possible value: daily
            precision (PrecisionEnum, optional): decimal place for currency
                price value

        Returns:
            CoinsMarketChart: Response from the API. Get historical market
                data include price, market cap, and 24hr volume (granularity
                auto)

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/{id}/market_chart')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('vs_currency')
                         .value(vs_currency))
            .query_param(Parameter()
                         .key('days')
                         .value(days))
            .query_param(Parameter()
                         .key('interval')
                         .value(interval))
            .query_param(Parameter()
                         .key('precision')
                         .value(precision))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CoinsMarketChart.from_dictionary)
        ).execute()

    def coins_id_market_chart_range(self,
                                    id,
                                    vs_currency,
                                    mfrom,
                                    to,
                                    precision=None):
        """Does a GET request to /coins/{id}/market_chart/range.

        This endpoint allows you to **get the historical chart data of a coin
        within certain time range in UNIX along with price, market cap and
        24hr volume based on particular coin ID**

        Args:
            id (str): coin ID <br> *refers to
                [`/coins/list`](/reference/coins-list).
            vs_currency (str): target currency of market data <br> *refers to
                [`/simple/supported_vs_currencies`](/reference/simple-supported
                -currencies).
            mfrom (int): starting date in UNIX timestamp
            to (int): ending date in UNIX timestamp
            precision (PrecisionEnum, optional): decimal place for currency
                price value

        Returns:
            CoinsMarketChartRange: Response from the API. Get historical
                market data include price, market cap, and 24hr volume
                (granularity auto)

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/{id}/market_chart/range')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('vs_currency')
                         .value(vs_currency))
            .query_param(Parameter()
                         .key('from')
                         .value(mfrom))
            .query_param(Parameter()
                         .key('to')
                         .value(to))
            .query_param(Parameter()
                         .key('precision')
                         .value(precision))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CoinsMarketChartRange.from_dictionary)
        ).execute()

    def coins_id_ohlc(self,
                      id,
                      vs_currency,
                      days,
                      precision=None):
        """Does a GET request to /coins/{id}/ohlc.

        This endpoint allows you to **get the OHLC chart (Open, High, Low,
        Close) of a coin based on particular coin ID**

        Args:
            id (str): coin ID <br> *refers to
                [`/coins/list`](/reference/coins-list).
            vs_currency (str): target currency of price data <br> *refers to
                [`/simple/supported_vs_currencies`](/reference/simple-supported
                -currencies).
            days (DaysEnum): data up to number of days ago
            precision (PrecisionEnum, optional): decimal place for currency
                price value

        Returns:
            List[float]: Response from the API. Get coin's OHLC

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/coins/{id}/ohlc')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('vs_currency')
                         .value(vs_currency))
            .query_param(Parameter()
                         .key('days')
                         .value(days))
            .query_param(Parameter()
                         .key('precision')
                         .value(precision))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
        ).execute()



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Image(object):

    """Implementation of the 'Image' model.

    coin image url

    Attributes:
        thumb (str): The model property of type str.
        small (str): The model property of type str.
        large (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "thumb": 'thumb',
        "small": 'small',
        "large": 'large'
    }

    _optionals = [
        'thumb',
        'small',
        'large',
    ]

    def __init__(self,
                 thumb=APIHelper.SKIP,
                 small=APIHelper.SKIP,
                 large=APIHelper.SKIP):
        """Constructor for the Image class"""

        # Initialize members of the class
        if thumb is not APIHelper.SKIP:
            self.thumb = thumb 
        if small is not APIHelper.SKIP:
            self.small = small 
        if large is not APIHelper.SKIP:
            self.large = large 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        thumb = dictionary.get("thumb") if dictionary.get("thumb") else APIHelper.SKIP
        small = dictionary.get("small") if dictionary.get("small") else APIHelper.SKIP
        large = dictionary.get("large") if dictionary.get("large") else APIHelper.SKIP
        # Return an object of this model
        return cls(thumb,
                   small,
                   large)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'thumb={(self.thumb if hasattr(self, "thumb") else None)!r}, '
                f'small={(self.small if hasattr(self, "small") else None)!r}, '
                f'large={(self.large if hasattr(self, "large") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'thumb={(self.thumb if hasattr(self, "thumb") else None)!s}, '
                f'small={(self.small if hasattr(self, "small") else None)!s}, '
                f'large={(self.large if hasattr(self, "large") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order1Enum(object):

    """Implementation of the 'order1' enum.

    Attributes:
        TRUST_SCORE_DESC: The enum member of type str.
        TRUST_SCORE_ASC: The enum member of type str.
        VOLUME_DESC: The enum member of type str.
        VOLUME_ASC: The enum member of type str.

    """
    TRUST_SCORE_DESC = 'trust_score_desc'

    TRUST_SCORE_ASC = 'trust_score_asc'

    VOLUME_DESC = 'volume_desc'

    VOLUME_ASC = 'volume_asc'




# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Links1(object):

    """Implementation of the 'Links1' model.

    NFT collection links

    Attributes:
        homepage (str): The model property of type str.
        twitter (str): The model property of type str.
        discord (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "homepage": 'homepage',
        "twitter": 'twitter',
        "discord": 'discord'
    }

    _optionals = [
        'homepage',
        'twitter',
        'discord',
    ]

    def __init__(self,
                 homepage=APIHelper.SKIP,
                 twitter=APIHelper.SKIP,
                 discord=APIHelper.SKIP):
        """Constructor for the Links1 class"""

        # Initialize members of the class
        if homepage is not APIHelper.SKIP:
            self.homepage = homepage 
        if twitter is not APIHelper.SKIP:
            self.twitter = twitter 
        if discord is not APIHelper.SKIP:
            self.discord = discord 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        homepage = dictionary.get("homepage") if dictionary.get("homepage") else APIHelper.SKIP
        twitter = dictionary.get("twitter") if dictionary.get("twitter") else APIHelper.SKIP
        discord = dictionary.get("discord") if dictionary.get("discord") else APIHelper.SKIP
        # Return an object of this model
        return cls(homepage,
                   twitter,
                   discord)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'homepage={(self.homepage if hasattr(self, "homepage") else None)!r}, '
                f'twitter={(self.twitter if hasattr(self, "twitter") else None)!r}, '
                f'discord={(self.discord if hasattr(self, "discord") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'homepage={(self.homepage if hasattr(self, "homepage") else None)!s}, '
                f'twitter={(self.twitter if hasattr(self, "twitter") else None)!s}, '
                f'discord={(self.discord if hasattr(self, "discord") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class PublicInterestStats(object):

    """Implementation of the 'PublicInterestStats' model.

    coin public interest stats

    Attributes:
        alexa_rank (float): coin alexa rank
        bing_matches (float): coin bing matches

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "alexa_rank": 'alexa_rank',
        "bing_matches": 'bing_matches'
    }

    _optionals = [
        'alexa_rank',
        'bing_matches',
    ]

    def __init__(self,
                 alexa_rank=APIHelper.SKIP,
                 bing_matches=APIHelper.SKIP):
        """Constructor for the PublicInterestStats class"""

        # Initialize members of the class
        if alexa_rank is not APIHelper.SKIP:
            self.alexa_rank = alexa_rank 
        if bing_matches is not APIHelper.SKIP:
            self.bing_matches = bing_matches 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        alexa_rank = dictionary.get("alexa_rank") if dictionary.get("alexa_rank") else APIHelper.SKIP
        bing_matches = dictionary.get("bing_matches") if dictionary.get("bing_matches") else APIHelper.SKIP
        # Return an object of this model
        return cls(alexa_rank,
                   bing_matches)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'alexa_rank={(self.alexa_rank if hasattr(self, "alexa_rank") else None)!r}, '
                f'bing_matches={(self.bing_matches if hasattr(self, "bing_matches") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'alexa_rank={(self.alexa_rank if hasattr(self, "alexa_rank") else None)!s}, '
                f'bing_matches={(self.bing_matches if hasattr(self, "bing_matches") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.data_1 import Data1


class Nft1(object):

    """Implementation of the 'Nft1' model.

    Attributes:
        id (str): NFT collection ID
        name (str): NFT collection name
        symbol (str): NFT collection symbol
        thumb (str): NFT collection thumb image url
        nft_contract_id (float): The model property of type float.
        native_currency_symbol (str): NFT collection native currency symbol
        floor_price_in_native_currency (float): NFT collection floor price in
            native currency
        floor_price_24_h_percentage_change (float): NFT collection floor price
            24 hours percentage change
        data (Data1): The model property of type Data1.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "name": 'name',
        "symbol": 'symbol',
        "thumb": 'thumb',
        "nft_contract_id": 'nft_contract_id',
        "native_currency_symbol": 'native_currency_symbol',
        "floor_price_in_native_currency": 'floor_price_in_native_currency',
        "floor_price_24_h_percentage_change": 'floor_price_24h_percentage_change',
        "data": 'data'
    }

    _optionals = [
        'id',
        'name',
        'symbol',
        'thumb',
        'nft_contract_id',
        'native_currency_symbol',
        'floor_price_in_native_currency',
        'floor_price_24_h_percentage_change',
        'data',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 symbol=APIHelper.SKIP,
                 thumb=APIHelper.SKIP,
                 nft_contract_id=APIHelper.SKIP,
                 native_currency_symbol=APIHelper.SKIP,
                 floor_price_in_native_currency=APIHelper.SKIP,
                 floor_price_24_h_percentage_change=APIHelper.SKIP,
                 data=APIHelper.SKIP):
        """Constructor for the Nft1 class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if symbol is not APIHelper.SKIP:
            self.symbol = symbol 
        if thumb is not APIHelper.SKIP:
            self.thumb = thumb 
        if nft_contract_id is not APIHelper.SKIP:
            self.nft_contract_id = nft_contract_id 
        if native_currency_symbol is not APIHelper.SKIP:
            self.native_currency_symbol = native_currency_symbol 
        if floor_price_in_native_currency is not APIHelper.SKIP:
            self.floor_price_in_native_currency = floor_price_in_native_currency 
        if floor_price_24_h_percentage_change is not APIHelper.SKIP:
            self.floor_price_24_h_percentage_change = floor_price_24_h_percentage_change 
        if data is not APIHelper.SKIP:
            self.data = data 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        symbol = dictionary.get("symbol") if dictionary.get("symbol") else APIHelper.SKIP
        thumb = dictionary.get("thumb") if dictionary.get("thumb") else APIHelper.SKIP
        nft_contract_id = dictionary.get("nft_contract_id") if dictionary.get("nft_contract_id") else APIHelper.SKIP
        native_currency_symbol = dictionary.get("native_currency_symbol") if dictionary.get("native_currency_symbol") else APIHelper.SKIP
        floor_price_in_native_currency = dictionary.get("floor_price_in_native_currency") if dictionary.get("floor_price_in_native_currency") else APIHelper.SKIP
        floor_price_24_h_percentage_change = dictionary.get("floor_price_24h_percentage_change") if dictionary.get("floor_price_24h_percentage_change") else APIHelper.SKIP
        data = Data1.from_dictionary(dictionary.get('data')) if 'data' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   name,
                   symbol,
                   thumb,
                   nft_contract_id,
                   native_currency_symbol,
                   floor_price_in_native_currency,
                   floor_price_24_h_percentage_change,
                   data)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!r}, '
                f'thumb={(self.thumb if hasattr(self, "thumb") else None)!r}, '
                f'nft_contract_id={(self.nft_contract_id if hasattr(self, "nft_contract_id") else None)!r}, '
                f'native_currency_symbol={(self.native_currency_symbol if hasattr(self, "native_currency_symbol") else None)!r}, '
                f'floor_price_in_native_currency={(self.floor_price_in_native_currency if hasattr(self, "floor_price_in_native_currency") else None)!r}, '
                f'floor_price_24_h_percentage_change={(self.floor_price_24_h_percentage_change if hasattr(self, "floor_price_24_h_percentage_change") else None)!r}, '
                f'data={(self.data if hasattr(self, "data") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'symbol={(self.symbol if hasattr(self, "symbol") else None)!s}, '
                f'thumb={(self.thumb if hasattr(self, "thumb") else None)!s}, '
                f'nft_contract_id={(self.nft_contract_id if hasattr(self, "nft_contract_id") else None)!s}, '
                f'native_currency_symbol={(self.native_currency_symbol if hasattr(self, "native_currency_symbol") else None)!s}, '
                f'floor_price_in_native_currency={(self.floor_price_in_native_currency if hasattr(self, "floor_price_in_native_currency") else None)!s}, '
                f'floor_price_24_h_percentage_change={(self.floor_price_24_h_percentage_change if hasattr(self, "floor_price_24_h_percentage_change") else None)!s}, '
                f'data={(self.data if hasattr(self, "data") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.configuration import Server
from coingeckopublicapiv3.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from coingeckopublicapiv3.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from apimatic_core.authentication.multiple.or_auth_group import Or
from coingeckopublicapiv3.models.asset_platform import AssetPlatform
from coingeckopublicapiv3.models.token_lists import TokenLists


class AssetPlatformsController(BaseController):

    """A Controller to access Endpoints in the coingeckopublicapiv3 API."""
    def __init__(self, config):
        super(AssetPlatformsController, self).__init__(config)

    def asset_platforms_list(self,
                             filter=None):
        """Does a GET request to /asset_platforms.

        This endpoint allows you to **query all the asset platforms on
        CoinGecko**

        Args:
            filter (FilterEnum, optional): apply relevant filters to results

        Returns:
            List[AssetPlatform]: Response from the API. List all asset
                platforms

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/asset_platforms')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('filter')
                         .value(filter))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AssetPlatform.from_dictionary)
        ).execute()

    def token_lists(self,
                    asset_platform_id):
        """Does a GET request to /token_lists/{asset_platform_id}/all.json.

        This endpoint allows you to **get full list of tokens of a blockchain
        network (asset platform) that is supported by [Ethereum token list
        standard](https://tokenlists.org/)**

        Args:
            asset_platform_id (str): asset platform ID <br> *refers to
                [`/asset_platforms`](/reference/asset-platforms-list)

        Returns:
            TokenLists: Response from the API. List all tokens on CoinGecko
                based on asset platform ID

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/token_lists/{asset_platform_id}/all.json')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('asset_platform_id')
                            .value(asset_platform_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Or(Single('apiKeyAuth'), Single('apiKeyQueryParam')))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(TokenLists.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper


class Data1(object):

    """Implementation of the 'Data1' model.

    Attributes:
        floor_price (str): NFT collection floor price
        floor_price_in_usd_24_h_percentage_change (str): NFT collection floor
            price in usd 24 hours percentage change
        h_24_volume (str): NFT collection volume in 24 hours
        h_24_average_sale_price (str): NFT collection 24 hours average sale
            price
        sparkline (str): NFT collection sparkline image url
        content (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "floor_price": 'floor_price',
        "floor_price_in_usd_24_h_percentage_change": 'floor_price_in_usd_24h_percentage_change',
        "h_24_volume": 'h24_volume',
        "h_24_average_sale_price": 'h24_average_sale_price',
        "sparkline": 'sparkline',
        "content": 'content'
    }

    _optionals = [
        'floor_price',
        'floor_price_in_usd_24_h_percentage_change',
        'h_24_volume',
        'h_24_average_sale_price',
        'sparkline',
        'content',
    ]

    def __init__(self,
                 floor_price=APIHelper.SKIP,
                 floor_price_in_usd_24_h_percentage_change=APIHelper.SKIP,
                 h_24_volume=APIHelper.SKIP,
                 h_24_average_sale_price=APIHelper.SKIP,
                 sparkline=APIHelper.SKIP,
                 content=APIHelper.SKIP):
        """Constructor for the Data1 class"""

        # Initialize members of the class
        if floor_price is not APIHelper.SKIP:
            self.floor_price = floor_price 
        if floor_price_in_usd_24_h_percentage_change is not APIHelper.SKIP:
            self.floor_price_in_usd_24_h_percentage_change = floor_price_in_usd_24_h_percentage_change 
        if h_24_volume is not APIHelper.SKIP:
            self.h_24_volume = h_24_volume 
        if h_24_average_sale_price is not APIHelper.SKIP:
            self.h_24_average_sale_price = h_24_average_sale_price 
        if sparkline is not APIHelper.SKIP:
            self.sparkline = sparkline 
        if content is not APIHelper.SKIP:
            self.content = content 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        floor_price = dictionary.get("floor_price") if dictionary.get("floor_price") else APIHelper.SKIP
        floor_price_in_usd_24_h_percentage_change = dictionary.get("floor_price_in_usd_24h_percentage_change") if dictionary.get("floor_price_in_usd_24h_percentage_change") else APIHelper.SKIP
        h_24_volume = dictionary.get("h24_volume") if dictionary.get("h24_volume") else APIHelper.SKIP
        h_24_average_sale_price = dictionary.get("h24_average_sale_price") if dictionary.get("h24_average_sale_price") else APIHelper.SKIP
        sparkline = dictionary.get("sparkline") if dictionary.get("sparkline") else APIHelper.SKIP
        content = dictionary.get("content") if dictionary.get("content") else APIHelper.SKIP
        # Return an object of this model
        return cls(floor_price,
                   floor_price_in_usd_24_h_percentage_change,
                   h_24_volume,
                   h_24_average_sale_price,
                   sparkline,
                   content)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'floor_price={(self.floor_price if hasattr(self, "floor_price") else None)!r}, '
                f'floor_price_in_usd_24_h_percentage_change={(self.floor_price_in_usd_24_h_percentage_change if hasattr(self, "floor_price_in_usd_24_h_percentage_change") else None)!r}, '
                f'h_24_volume={(self.h_24_volume if hasattr(self, "h_24_volume") else None)!r}, '
                f'h_24_average_sale_price={(self.h_24_average_sale_price if hasattr(self, "h_24_average_sale_price") else None)!r}, '
                f'sparkline={(self.sparkline if hasattr(self, "sparkline") else None)!r}, '
                f'content={(self.content if hasattr(self, "content") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'floor_price={(self.floor_price if hasattr(self, "floor_price") else None)!s}, '
                f'floor_price_in_usd_24_h_percentage_change={(self.floor_price_in_usd_24_h_percentage_change if hasattr(self, "floor_price_in_usd_24_h_percentage_change") else None)!s}, '
                f'h_24_volume={(self.h_24_volume if hasattr(self, "h_24_volume") else None)!s}, '
                f'h_24_average_sale_price={(self.h_24_average_sale_price if hasattr(self, "h_24_average_sale_price") else None)!s}, '
                f'sparkline={(self.sparkline if hasattr(self, "sparkline") else None)!s}, '
                f'content={(self.content if hasattr(self, "content") else None)!s})')



# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from coingeckopublicapiv3.api_helper import APIHelper
from coingeckopublicapiv3.models.categories_2 import Categories2
from coingeckopublicapiv3.models.coin_1 import Coin1
from coingeckopublicapiv3.models.nft_1 import Nft1


class TrendingSearch(object):

    """Implementation of the 'TrendingSearch' model.

    Attributes:
        coins (List[Coin1]): The model property of type List[Coin1].
        nfts (List[Nft1]): The model property of type List[Nft1].
        categories (List[Categories2]): The model property of type
            List[Categories2].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "coins": 'coins',
        "nfts": 'nfts',
        "categories": 'categories'
    }

    _optionals = [
        'coins',
        'nfts',
        'categories',
    ]

    def __init__(self,
                 coins=APIHelper.SKIP,
                 nfts=APIHelper.SKIP,
                 categories=APIHelper.SKIP):
        """Constructor for the TrendingSearch class"""

        # Initialize members of the class
        if coins is not APIHelper.SKIP:
            self.coins = coins 
        if nfts is not APIHelper.SKIP:
            self.nfts = nfts 
        if categories is not APIHelper.SKIP:
            self.categories = categories 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        coins = None
        if dictionary.get('coins') is not None:
            coins = [Coin1.from_dictionary(x) for x in dictionary.get('coins')]
        else:
            coins = APIHelper.SKIP
        nfts = None
        if dictionary.get('nfts') is not None:
            nfts = [Nft1.from_dictionary(x) for x in dictionary.get('nfts')]
        else:
            nfts = APIHelper.SKIP
        categories = None
        if dictionary.get('categories') is not None:
            categories = [Categories2.from_dictionary(x) for x in dictionary.get('categories')]
        else:
            categories = APIHelper.SKIP
        # Return an object of this model
        return cls(coins,
                   nfts,
                   categories)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'coins={(self.coins if hasattr(self, "coins") else None)!r}, '
                f'nfts={(self.nfts if hasattr(self, "nfts") else None)!r}, '
                f'categories={(self.categories if hasattr(self, "categories") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'coins={(self.coins if hasattr(self, "coins") else None)!s}, '
                f'nfts={(self.nfts if hasattr(self, "nfts") else None)!s}, '
                f'categories={(self.categories if hasattr(self, "categories") else None)!s})')
